Class: Google::Apis::GkehubV1beta::ClusterUpgradeFleetSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

ClusterUpgrade: The configuration for the fleet-level ClusterUpgrade feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ClusterUpgradeFleetSpec

Returns a new instance of ClusterUpgradeFleetSpec.



433
434
435
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 433

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#gke_upgrade_overridesArray<Google::Apis::GkehubV1beta::ClusterUpgradeGkeUpgradeOverride>

Allow users to override some properties of each GKE upgrade. Corresponds to the JSON property gkeUpgradeOverrides



417
418
419
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 417

def gke_upgrade_overrides
  @gke_upgrade_overrides
end

#post_conditionsGoogle::Apis::GkehubV1beta::ClusterUpgradePostConditions

Post conditional checks after an upgrade has been applied on all eligible clusters. Corresponds to the JSON property postConditions



423
424
425
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 423

def post_conditions
  @post_conditions
end

#upstream_fleetsArray<String>

This fleet consumes upgrades that have COMPLETE status code in the upstream fleets. See UpgradeStatus.Code for code definitions. The fleet name should be either fleet project number or id. This is defined as repeated for future proof reasons. Initial implementation will enforce at most one upstream fleet. Corresponds to the JSON property upstreamFleets

Returns:

  • (Array<String>)


431
432
433
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 431

def upstream_fleets
  @upstream_fleets
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



438
439
440
441
442
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 438

def update!(**args)
  @gke_upgrade_overrides = args[:gke_upgrade_overrides] if args.key?(:gke_upgrade_overrides)
  @post_conditions = args[:post_conditions] if args.key?(:post_conditions)
  @upstream_fleets = args[:upstream_fleets] if args.key?(:upstream_fleets)
end