Class: Google::Apis::GkehubV1beta::ConfigManagementConfigSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConfigManagementConfigSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
State information for ConfigSync
Instance Attribute Summary collapse
-
#cluster_level_stop_syncing_state ⇒ String
Output only.
-
#cr_count ⇒ Fixnum
Output only.
-
#deployment_state ⇒ Google::Apis::GkehubV1beta::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster Corresponds to the JSON property
deploymentState. -
#errors ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementConfigSyncError>
Output only.
-
#reposync_crd ⇒ String
Output only.
-
#rootsync_crd ⇒ String
Output only.
-
#state ⇒ String
Output only.
-
#sync_state ⇒ Google::Apis::GkehubV1beta::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property
syncState. -
#version ⇒ Google::Apis::GkehubV1beta::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementConfigSyncState
constructor
A new instance of ConfigManagementConfigSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementConfigSyncState
Returns a new instance of ConfigManagementConfigSyncState.
1259 1260 1261 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1259 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_level_stop_syncing_state ⇒ String
Output only. Whether syncing resources to the cluster is stopped at the
cluster level.
Corresponds to the JSON property clusterLevelStopSyncingState
1216 1217 1218 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1216 def cluster_level_stop_syncing_state @cluster_level_stop_syncing_state end |
#cr_count ⇒ Fixnum
Output only. The number of RootSync and RepoSync CRs in the cluster.
Corresponds to the JSON property crCount
1221 1222 1223 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1221 def cr_count @cr_count end |
#deployment_state ⇒ Google::Apis::GkehubV1beta::ConfigManagementConfigSyncDeploymentState
The state of ConfigSync's deployment on a cluster
Corresponds to the JSON property deploymentState
1226 1227 1228 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1226 def deployment_state @deployment_state end |
#errors ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementConfigSyncError>
Output only. Errors pertaining to the installation of Config Sync.
Corresponds to the JSON property errors
1231 1232 1233 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1231 def errors @errors end |
#reposync_crd ⇒ String
Output only. The state of the Reposync CRD
Corresponds to the JSON property reposyncCrd
1236 1237 1238 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1236 def reposync_crd @reposync_crd end |
#rootsync_crd ⇒ String
Output only. The state of the RootSync CRD
Corresponds to the JSON property rootsyncCrd
1241 1242 1243 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1241 def rootsync_crd @rootsync_crd end |
#state ⇒ String
Output only. The state of CS This field summarizes the other fields in this
message.
Corresponds to the JSON property state
1247 1248 1249 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1247 def state @state end |
#sync_state ⇒ Google::Apis::GkehubV1beta::ConfigManagementSyncState
State indicating an ACM's progress syncing configurations to a cluster
Corresponds to the JSON property syncState
1252 1253 1254 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1252 def sync_state @sync_state end |
#version ⇒ Google::Apis::GkehubV1beta::ConfigManagementConfigSyncVersion
Specific versioning information pertaining to ConfigSync's Pods
Corresponds to the JSON property version
1257 1258 1259 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1257 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1264 1265 1266 1267 1268 1269 1270 1271 1272 1273 1274 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1264 def update!(**args) @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state) @cr_count = args[:cr_count] if args.key?(:cr_count) @deployment_state = args[:deployment_state] if args.key?(:deployment_state) @errors = args[:errors] if args.key?(:errors) @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd) @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd) @state = args[:state] if args.key?(:state) @sync_state = args[:sync_state] if args.key?(:sync_state) @version = args[:version] if args.key?(:version) end |