Class: Google::Apis::GkehubV1beta::ConfigManagementConfigSyncVersion

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Specific versioning information pertaining to ConfigSync's Pods

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncVersion

Returns a new instance of ConfigManagementConfigSyncVersion.



1312
1313
1314
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1312

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#admission_webhookString

Version of the deployed admission-webhook pod Corresponds to the JSON property admissionWebhook

Returns:

  • (String)


1270
1271
1272
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1270

def admission_webhook
  @admission_webhook
end

#git_syncString

Version of the deployed git-sync pod Corresponds to the JSON property gitSync

Returns:

  • (String)


1275
1276
1277
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1275

def git_sync
  @git_sync
end

#importerString

Version of the deployed importer pod Corresponds to the JSON property importer

Returns:

  • (String)


1280
1281
1282
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1280

def importer
  @importer
end

#monitorString

Version of the deployed monitor pod Corresponds to the JSON property monitor

Returns:

  • (String)


1285
1286
1287
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1285

def monitor
  @monitor
end

#otel_collectorString

Version of the deployed otel-collector pod Corresponds to the JSON property otelCollector

Returns:

  • (String)


1290
1291
1292
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1290

def otel_collector
  @otel_collector
end

#reconciler_managerString

Version of the deployed reconciler-manager pod Corresponds to the JSON property reconcilerManager

Returns:

  • (String)


1295
1296
1297
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1295

def reconciler_manager
  @reconciler_manager
end

#resource_group_controller_managerString

Version of the deployed resource-group-controller-manager pod Corresponds to the JSON property resourceGroupControllerManager

Returns:

  • (String)


1300
1301
1302
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1300

def resource_group_controller_manager
  @resource_group_controller_manager
end

#root_reconcilerString

Version of the deployed reconciler container in root-reconciler pod Corresponds to the JSON property rootReconciler

Returns:

  • (String)


1305
1306
1307
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1305

def root_reconciler
  @root_reconciler
end

#syncerString

Version of the deployed syncer pod Corresponds to the JSON property syncer

Returns:

  • (String)


1310
1311
1312
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1310

def syncer
  @syncer
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1317
1318
1319
1320
1321
1322
1323
1324
1325
1326
1327
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1317

def update!(**args)
  @admission_webhook = args[:admission_webhook] if args.key?(:admission_webhook)
  @git_sync = args[:git_sync] if args.key?(:git_sync)
  @importer = args[:importer] if args.key?(:importer)
  @monitor = args[:monitor] if args.key?(:monitor)
  @otel_collector = args[:otel_collector] if args.key?(:otel_collector)
  @reconciler_manager = args[:reconciler_manager] if args.key?(:reconciler_manager)
  @resource_group_controller_manager = args[:resource_group_controller_manager] if args.key?(:resource_group_controller_manager)
  @root_reconciler = args[:root_reconciler] if args.key?(:root_reconciler)
  @syncer = args[:syncer] if args.key?(:syncer)
end