Class: Google::Apis::GkehubV1beta::ConfigManagementDeploymentOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Configuration for a deployment override.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementDeploymentOverride

Returns a new instance of ConfigManagementDeploymentOverride.



1421
1422
1423
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1421

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#containersArray<Google::Apis::GkehubV1beta::ConfigManagementContainerOverride>

Optional. The containers of the deployment resource to be overridden. Corresponds to the JSON property containers



1409
1410
1411
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1409

def containers
  @containers
end

#deployment_nameString

Required. The name of the deployment resource to be overridden. Corresponds to the JSON property deploymentName

Returns:

  • (String)


1414
1415
1416
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1414

def deployment_name
  @deployment_name
end

#deployment_namespaceString

Required. The namespace of the deployment resource to be overridden. Corresponds to the JSON property deploymentNamespace

Returns:

  • (String)


1419
1420
1421
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1419

def deployment_namespace
  @deployment_namespace
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1426
1427
1428
1429
1430
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1426

def update!(**args)
  @containers = args[:containers] if args.key?(:containers)
  @deployment_name = args[:deployment_name] if args.key?(:deployment_name)
  @deployment_namespace = args[:deployment_namespace] if args.key?(:deployment_namespace)
end