Class: Google::Apis::GkehubV1beta::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1772
1773
1774
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1772

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV1beta::ConfigManagementBinauthzConfig

Configuration for Binauthz Corresponds to the JSON property binauthz



1727
1728
1729
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1727

def binauthz
  @binauthz
end

#clusterString

Optional. User-specified cluster name used by the Config Sync cluster-name- selector annotation or ClusterSelector object, for applying configs to only a subset of clusters. Read more about the cluster-name-selector annotation and ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/ config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this field if a name different from the cluster's fleet membership name is used by the Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1738
1739
1740
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1738

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1beta::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1743
1744
1745
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1743

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1748
1749
1750
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1748

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Deprecated: Automatic Feature management is in Preview and is unavailable in version 1.21.0 and later, after which Config Sync only supports manual upgrades. If set to manual upgrades, clear this field instead, which is behaviorally equivalent but helps prevent compatibility issues with newer fields. Corresponds to the JSON property management

Returns:

  • (String)


1757
1758
1759
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1757

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1762
1763
1764
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1762

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of Config Sync to install. Defaults to the latest supported Config Sync version if the config_sync field is enabled. See supported versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get- support-config-sync#version_support_policy. Corresponds to the JSON property version

Returns:

  • (String)


1770
1771
1772
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1770

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1777
1778
1779
1780
1781
1782
1783
1784
1785
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1777

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end