Class: Google::Apis::GkehubV1beta::ConfigManagementPolicyControllerVersion
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConfigManagementPolicyControllerVersion
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
The build version of Gatekeeper Policy Controller is using.
Instance Attribute Summary collapse
-
#version ⇒ String
The gatekeeper image tag that is composed of ACM version, git tag, build number.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementPolicyControllerVersion
constructor
A new instance of ConfigManagementPolicyControllerVersion.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementPolicyControllerVersion
Returns a new instance of ConfigManagementPolicyControllerVersion.
2098 2099 2100 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2098 def initialize(**args) update!(**args) end |
Instance Attribute Details
#version ⇒ String
The gatekeeper image tag that is composed of ACM version, git tag, build
number.
Corresponds to the JSON property version
2096 2097 2098 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2096 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2103 2104 2105 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2103 def update!(**args) @version = args[:version] if args.key?(:version) end |