Class: Google::Apis::GkehubV1beta::ConfigManagementSyncState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConfigManagementSyncState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
State indicating an ACM's progress syncing configurations to a cluster
Instance Attribute Summary collapse
-
#code ⇒ String
Sync status code Corresponds to the JSON property
code. -
#errors ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementSyncError>
A list of errors resulting from problematic configs.
-
#import_token ⇒ String
Token indicating the state of the importer.
-
#last_sync ⇒ String
Deprecated: use last_sync_time instead.
-
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property
lastSyncTime. -
#source_token ⇒ String
Token indicating the state of the repo.
-
#sync_token ⇒ String
Token indicating the state of the syncer.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementSyncState
constructor
A new instance of ConfigManagementSyncState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementSyncState
Returns a new instance of ConfigManagementSyncState.
2189 2190 2191 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2189 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Sync status code
Corresponds to the JSON property code
2153 2154 2155 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2153 def code @code end |
#errors ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementSyncError>
A list of errors resulting from problematic configs. This list will be
truncated after 100 errors, although it is unlikely for that many errors to
simultaneously exist.
Corresponds to the JSON property errors
2160 2161 2162 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2160 def errors @errors end |
#import_token ⇒ String
Token indicating the state of the importer.
Corresponds to the JSON property importToken
2165 2166 2167 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2165 def import_token @import_token end |
#last_sync ⇒ String
Deprecated: use last_sync_time instead. Timestamp of when ACM last
successfully synced the repo The time format is specified in https://golang.
org/pkg/time/#Time.String
Corresponds to the JSON property lastSync
2172 2173 2174 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2172 def last_sync @last_sync end |
#last_sync_time ⇒ String
Timestamp type of when ACM last successfully synced the repo
Corresponds to the JSON property lastSyncTime
2177 2178 2179 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2177 def last_sync_time @last_sync_time end |
#source_token ⇒ String
Token indicating the state of the repo.
Corresponds to the JSON property sourceToken
2182 2183 2184 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2182 def source_token @source_token end |
#sync_token ⇒ String
Token indicating the state of the syncer.
Corresponds to the JSON property syncToken
2187 2188 2189 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2187 def sync_token @sync_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2194 2195 2196 2197 2198 2199 2200 2201 2202 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2194 def update!(**args) @code = args[:code] if args.key?(:code) @errors = args[:errors] if args.key?(:errors) @import_token = args[:import_token] if args.key?(:import_token) @last_sync = args[:last_sync] if args.key?(:last_sync) @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time) @source_token = args[:source_token] if args.key?(:source_token) @sync_token = args[:sync_token] if args.key?(:sync_token) end |