Class: Google::Apis::GkehubV1beta::ConnectAgentResource
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConnectAgentResource
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
ConnectAgentResource represents a Kubernetes resource manifest for Connect Agent deployment.
Instance Attribute Summary collapse
-
#manifest ⇒ String
YAML manifest of the resource.
-
#type ⇒ Google::Apis::GkehubV1beta::TypeMeta
TypeMeta is the type information needed for content unmarshalling of Kubernetes resources in the manifest.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConnectAgentResource
constructor
A new instance of ConnectAgentResource.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConnectAgentResource
Returns a new instance of ConnectAgentResource.
2197 2198 2199 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2197 def initialize(**args) update!(**args) end |
Instance Attribute Details
#manifest ⇒ String
YAML manifest of the resource.
Corresponds to the JSON property manifest
2189 2190 2191 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2189 def manifest @manifest end |
#type ⇒ Google::Apis::GkehubV1beta::TypeMeta
TypeMeta is the type information needed for content unmarshalling of
Kubernetes resources in the manifest.
Corresponds to the JSON property type
2195 2196 2197 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2195 def type @type end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2202 2203 2204 2205 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2202 def update!(**args) @manifest = args[:manifest] if args.key?(:manifest) @type = args[:type] if args.key?(:type) end |