Class: Google::Apis::GkehubV1beta::IdentityServiceDiagnosticInterface

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Configuration options for the AIS diagnostic interface.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceDiagnosticInterface

Returns a new instance of IdentityServiceDiagnosticInterface.



3103
3104
3105
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3103

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#enabledBoolean Also known as: enabled?

Determines whether to enable the diagnostic interface. Corresponds to the JSON property enabled

Returns:

  • (Boolean)


3094
3095
3096
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3094

def enabled
  @enabled
end

#expiration_timeString

Determines the expiration time of the diagnostic interface enablement. When reached, requests to the interface would be automatically rejected. Corresponds to the JSON property expirationTime

Returns:

  • (String)


3101
3102
3103
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3101

def expiration_time
  @expiration_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3108
3109
3110
3111
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3108

def update!(**args)
  @enabled = args[:enabled] if args.key?(:enabled)
  @expiration_time = args[:expiration_time] if args.key?(:expiration_time)
end