Class: Google::Apis::GkehubV1beta::KubernetesMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

KubernetesMetadata provides informational metadata for Memberships representing Kubernetes clusters.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ KubernetesMetadata

Returns a new instance of KubernetesMetadata.



3655
3656
3657
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3655

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#kubernetes_api_server_versionString

Output only. Kubernetes API server version string as reported by /version. Corresponds to the JSON property kubernetesApiServerVersion

Returns:

  • (String)


3622
3623
3624
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3622

def kubernetes_api_server_version
  @kubernetes_api_server_version
end

#memory_mbFixnum

Output only. The total memory capacity as reported by the sum of all Kubernetes nodes resources, defined in MB. Corresponds to the JSON property memoryMb

Returns:

  • (Fixnum)


3628
3629
3630
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3628

def memory_mb
  @memory_mb
end

#node_countFixnum

Output only. Node count as reported by Kubernetes nodes resources. Corresponds to the JSON property nodeCount

Returns:

  • (Fixnum)


3633
3634
3635
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3633

def node_count
  @node_count
end

#node_provider_idString

Output only. Node providerID as reported by the first node in the list of nodes on the Kubernetes endpoint. On Kubernetes platforms that support zero- node clusters (like GKE on Google Cloud), the node_count will be zero and the node_provider_id will be empty. Corresponds to the JSON property nodeProviderId

Returns:

  • (String)


3641
3642
3643
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3641

def node_provider_id
  @node_provider_id
end

#update_timeString

Output only. The time at which these details were last updated. This update_time is different from the Membership-level update_time since EndpointDetails are updated internally for API consumers. Corresponds to the JSON property updateTime

Returns:

  • (String)


3648
3649
3650
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3648

def update_time
  @update_time
end

#vcpu_countFixnum

Output only. vCPU count as reported by Kubernetes nodes resources. Corresponds to the JSON property vcpuCount

Returns:

  • (Fixnum)


3653
3654
3655
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3653

def vcpu_count
  @vcpu_count
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3660
3661
3662
3663
3664
3665
3666
3667
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3660

def update!(**args)
  @kubernetes_api_server_version = args[:kubernetes_api_server_version] if args.key?(:kubernetes_api_server_version)
  @memory_mb = args[:memory_mb] if args.key?(:memory_mb)
  @node_count = args[:node_count] if args.key?(:node_count)
  @node_provider_id = args[:node_provider_id] if args.key?(:node_provider_id)
  @update_time = args[:update_time] if args.key?(:update_time)
  @vcpu_count = args[:vcpu_count] if args.key?(:vcpu_count)
end