Class: Google::Apis::GkehubV1beta::ListLocationsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListLocationsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
The response message for Locations.ListLocations.
Instance Attribute Summary collapse
-
#locations ⇒ Array<Google::Apis::GkehubV1beta::Location>
A list of locations that matches the specified filter in the request.
-
#next_page_token ⇒ String
The standard List next-page token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListLocationsResponse
constructor
A new instance of ListLocationsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListLocationsResponse
Returns a new instance of ListLocationsResponse.
3825 3826 3827 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3825 def initialize(**args) update!(**args) end |
Instance Attribute Details
#locations ⇒ Array<Google::Apis::GkehubV1beta::Location>
A list of locations that matches the specified filter in the request.
Corresponds to the JSON property locations
3818 3819 3820 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3818 def locations @locations end |
#next_page_token ⇒ String
The standard List next-page token.
Corresponds to the JSON property nextPageToken
3823 3824 3825 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3823 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3830 3831 3832 3833 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3830 def update!(**args) @locations = args[:locations] if args.key?(:locations) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |