Class: Google::Apis::GkehubV1beta::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
3940 3941 3942 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3940 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3928 3929 3930 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3928 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
3933 3934 3935 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3933 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3938 3939 3940 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3938 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3945 3946 3947 3948 3949 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3945 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |