Class: Google::Apis::GkehubV1beta::MembershipEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipEndpoint

Returns a new instance of MembershipEndpoint.



4448
4449
4450
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4448

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_clusterGoogle::Apis::GkehubV1beta::ApplianceCluster

ApplianceCluster contains information specific to GDC Edge Appliance Clusters. Corresponds to the JSON property applianceCluster



4406
4407
4408
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4406

def appliance_cluster
  @appliance_cluster
end

#edge_clusterGoogle::Apis::GkehubV1beta::EdgeCluster

EdgeCluster contains information specific to Google Edge Clusters. Corresponds to the JSON property edgeCluster



4411
4412
4413
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4411

def edge_cluster
  @edge_cluster
end

#gke_clusterGoogle::Apis::GkehubV1beta::GkeCluster

GkeCluster contains information specific to GKE clusters. Corresponds to the JSON property gkeCluster



4416
4417
4418
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4416

def gke_cluster
  @gke_cluster
end

#google_managedBoolean Also known as: google_managed?

Output only. Whether the lifecycle of this membership is managed by a google cluster platform service. Corresponds to the JSON property googleManaged

Returns:

  • (Boolean)


4422
4423
4424
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4422

def google_managed
  @google_managed
end

#kubernetes_metadataGoogle::Apis::GkehubV1beta::KubernetesMetadata

KubernetesMetadata provides informational metadata for Memberships representing Kubernetes clusters. Corresponds to the JSON property kubernetesMetadata



4429
4430
4431
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4429

def 
  @kubernetes_metadata
end

#kubernetes_resourceGoogle::Apis::GkehubV1beta::KubernetesResource

KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster. Corresponds to the JSON property kubernetesResource



4436
4437
4438
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4436

def kubernetes_resource
  @kubernetes_resource
end

#multi_cloud_clusterGoogle::Apis::GkehubV1beta::MultiCloudCluster

MultiCloudCluster contains information specific to GKE Multi-Cloud clusters. Corresponds to the JSON property multiCloudCluster



4441
4442
4443
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4441

def multi_cloud_cluster
  @multi_cloud_cluster
end

#on_prem_clusterGoogle::Apis::GkehubV1beta::OnPremCluster

OnPremCluster contains information specific to GKE On-Prem clusters. Corresponds to the JSON property onPremCluster



4446
4447
4448
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4446

def on_prem_cluster
  @on_prem_cluster
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4453
4454
4455
4456
4457
4458
4459
4460
4461
4462
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4453

def update!(**args)
  @appliance_cluster = args[:appliance_cluster] if args.key?(:appliance_cluster)
  @edge_cluster = args[:edge_cluster] if args.key?(:edge_cluster)
  @gke_cluster = args[:gke_cluster] if args.key?(:gke_cluster)
  @google_managed = args[:google_managed] if args.key?(:google_managed)
  @kubernetes_metadata = args[:kubernetes_metadata] if args.key?(:kubernetes_metadata)
  @kubernetes_resource = args[:kubernetes_resource] if args.key?(:kubernetes_resource)
  @multi_cloud_cluster = args[:multi_cloud_cluster] if args.key?(:multi_cloud_cluster)
  @on_prem_cluster = args[:on_prem_cluster] if args.key?(:on_prem_cluster)
end