Class: Google::Apis::GkehubV1beta::MembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Cloud Build: Configurations for each Cloud Build enabled cluster.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipSpec

Returns a new instance of MembershipSpec.



4603
4604
4605
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4603

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#security_policyString

Whether it is allowed to run the privileged builds on the cluster or not. Corresponds to the JSON property securityPolicy

Returns:

  • (String)


4596
4597
4598
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4596

def security_policy
  @security_policy
end

#versionString

Version of the cloud build software on the cluster. Corresponds to the JSON property version

Returns:

  • (String)


4601
4602
4603
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4601

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4608
4609
4610
4611
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4608

def update!(**args)
  @security_policy = args[:security_policy] if args.key?(:security_policy)
  @version = args[:version] if args.key?(:version)
end