Class: Google::Apis::GkehubV1beta::MonitoringConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services. It can be set from empty to non-empty, but can't be mutated directly to prevent accidentally breaking the constinousty of metrics.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MonitoringConfig

Returns a new instance of MonitoringConfig.



4530
4531
4532
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4530

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#clusterString

Optional. Cluster name used to report metrics. For Anthos on VMWare/Baremetal/ MultiCloud clusters, it would be in format cluster_type/cluster_name, e.g., "awsClusters/cluster_1". Corresponds to the JSON property cluster

Returns:

  • (String)


4504
4505
4506
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4504

def cluster
  @cluster
end

#cluster_hashString

Optional. For GKE and Multicloud clusters, this is the UUID of the cluster resource. For VMWare and Baremetal clusters, this is the kube-system UID. Corresponds to the JSON property clusterHash

Returns:

  • (String)


4510
4511
4512
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4510

def cluster_hash
  @cluster_hash
end

#kubernetes_metrics_prefixString

Optional. Kubernetes system metrics, if available, are written to this prefix. This defaults to kubernetes.io for GKE, and kubernetes.io/anthos for Anthos eventually. Noted: Anthos MultiCloud will have kubernetes.io prefix today but will migration to be under kubernetes.io/anthos. Corresponds to the JSON property kubernetesMetricsPrefix

Returns:

  • (String)


4518
4519
4520
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4518

def kubernetes_metrics_prefix
  @kubernetes_metrics_prefix
end

#locationString

Optional. Location used to report Metrics Corresponds to the JSON property location

Returns:

  • (String)


4523
4524
4525
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4523

def location
  @location
end

#project_idString

Optional. Project used to report Metrics Corresponds to the JSON property projectId

Returns:

  • (String)


4528
4529
4530
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4528

def project_id
  @project_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4535
4536
4537
4538
4539
4540
4541
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4535

def update!(**args)
  @cluster = args[:cluster] if args.key?(:cluster)
  @cluster_hash = args[:cluster_hash] if args.key?(:cluster_hash)
  @kubernetes_metrics_prefix = args[:kubernetes_metrics_prefix] if args.key?(:kubernetes_metrics_prefix)
  @location = args[:location] if args.key?(:location)
  @project_id = args[:project_id] if args.key?(:project_id)
end