Class: Google::Apis::GkehubV1beta::Namespace

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Namespace represents a namespace across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Namespace

Returns a new instance of Namespace.



4660
4661
4662
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4660

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the namespace was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4611
4612
4613
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4611

def create_time
  @create_time
end

#delete_timeString

Output only. When the namespace was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


4616
4617
4618
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4616

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Namespace. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


4621
4622
4623
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4621

def labels
  @labels
end

#nameString

The resource name for the namespace projects/project/locations/location/ namespaces/namespace` Corresponds to the JSON propertyname`

Returns:

  • (String)


4627
4628
4629
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4627

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Namespace-level cluster namespace labels. These labels are applied to the related namespace of the member clusters bound to the parent Scope. Scope-level labels (namespace_labels in the Fleet Scope resource) take precedence over Namespace-level labels if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


4636
4637
4638
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4636

def namespace_labels
  @namespace_labels
end

#scopeString

Required. Scope associated with the namespace Corresponds to the JSON property scope

Returns:

  • (String)


4641
4642
4643
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4641

def scope
  @scope
end

#stateGoogle::Apis::GkehubV1beta::NamespaceLifecycleState

NamespaceLifecycleState describes the state of a Namespace resource. Corresponds to the JSON property state



4646
4647
4648
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4646

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all namespace resources. If a namespace resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


4653
4654
4655
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4653

def uid
  @uid
end

#update_timeString

Output only. When the namespace was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


4658
4659
4660
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4658

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4665
4666
4667
4668
4669
4670
4671
4672
4673
4674
4675
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4665

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @scope = args[:scope] if args.key?(:scope)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end