Class: Google::Apis::GkehubV1beta::OperationMetadata

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Represents the metadata of the long-running operation.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ OperationMetadata

Returns a new instance of OperationMetadata.



5013
5014
5015
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5013

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#api_versionString

Output only. API version used to start the operation. Corresponds to the JSON property apiVersion

Returns:

  • (String)


4977
4978
4979
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4977

def api_version
  @api_version
end

#cancel_requestedBoolean Also known as: cancel_requested?

Output only. Identifies whether the user has requested cancellation of the operation. Operations that have successfully been cancelled have google. longrunning.Operation.error value with a google.rpc.Status.code of 1, corresponding to Code.CANCELLED. Corresponds to the JSON property cancelRequested

Returns:

  • (Boolean)


4985
4986
4987
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4985

def cancel_requested
  @cancel_requested
end

#create_timeString

Output only. The time the operation was created. Corresponds to the JSON property createTime

Returns:

  • (String)


4991
4992
4993
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4991

def create_time
  @create_time
end

#end_timeString

Output only. The time the operation finished running. Corresponds to the JSON property endTime

Returns:

  • (String)


4996
4997
4998
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4996

def end_time
  @end_time
end

#status_detailString

Output only. Human-readable status of the operation, if any. Corresponds to the JSON property statusDetail

Returns:

  • (String)


5001
5002
5003
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5001

def status_detail
  @status_detail
end

#targetString

Output only. Server-defined resource path for the target of the operation. Corresponds to the JSON property target

Returns:

  • (String)


5006
5007
5008
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5006

def target
  @target
end

#verbString

Output only. Name of the verb executed by the operation. Corresponds to the JSON property verb

Returns:

  • (String)


5011
5012
5013
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5011

def verb
  @verb
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5018
5019
5020
5021
5022
5023
5024
5025
5026
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5018

def update!(**args)
  @api_version = args[:api_version] if args.key?(:api_version)
  @cancel_requested = args[:cancel_requested] if args.key?(:cancel_requested)
  @create_time = args[:create_time] if args.key?(:create_time)
  @end_time = args[:end_time] if args.key?(:end_time)
  @status_detail = args[:status_detail] if args.key?(:status_detail)
  @target = args[:target] if args.key?(:target)
  @verb = args[:verb] if args.key?(:verb)
end