Class: Google::Apis::GkehubV1beta::PolicyControllerPolicyContentState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

The state of the policy controller policy content

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PolicyControllerPolicyContentState

Returns a new instance of PolicyControllerPolicyContentState.



5482
5483
5484
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5482

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bundle_statesHash<String,Google::Apis::GkehubV1beta::PolicyControllerOnClusterState>

The state of the any bundles included in the chosen version of the manifest Corresponds to the JSON property bundleStates



5470
5471
5472
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5470

def bundle_states
  @bundle_states
end

#referential_sync_config_stateGoogle::Apis::GkehubV1beta::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property referentialSyncConfigState



5475
5476
5477
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5475

def referential_sync_config_state
  @referential_sync_config_state
end

#template_library_stateGoogle::Apis::GkehubV1beta::PolicyControllerOnClusterState

OnClusterState represents the state of a sub-component of Policy Controller. Corresponds to the JSON property templateLibraryState



5480
5481
5482
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5480

def template_library_state
  @template_library_state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5487
5488
5489
5490
5491
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5487

def update!(**args)
  @bundle_states = args[:bundle_states] if args.key?(:bundle_states)
  @referential_sync_config_state = args[:referential_sync_config_state] if args.key?(:referential_sync_config_state)
  @template_library_state = args[:template_library_state] if args.key?(:template_library_state)
end