Class: Google::Apis::GkehubV1beta::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



5709
5710
5711
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5709

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5655
5656
5657
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5655

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5660
5661
5662
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5660

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


5665
5666
5667
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5665

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5670
5671
5672
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5670

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


5678
5679
5680
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5678

def name
  @name
end

#roleGoogle::Apis::GkehubV1beta::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



5683
5684
5685
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5683

def role
  @role
end

#stateGoogle::Apis::GkehubV1beta::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



5689
5690
5691
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5689

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5696
5697
5698
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5696

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5701
5702
5703
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5701

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


5707
5708
5709
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5707

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5714
5715
5716
5717
5718
5719
5720
5721
5722
5723
5724
5725
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5714

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end