Class: Google::Apis::GkehubV1beta::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

RolloutSequence defines the desired order of upgrades. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6188
6189
6190
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6188

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_configGoogle::Apis::GkehubV1beta::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property autoUpgradeConfig



6098
6099
6100
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6098

def auto_upgrade_config
  @auto_upgrade_config
end

#computed_release_channelString

Output only. The computed release channel used for the Rollout Sequence. Corresponds to the JSON property computedReleaseChannel

Returns:

  • (String)


6103
6104
6105
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6103

def computed_release_channel
  @computed_release_channel
end

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6108
6109
6110
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6108

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6113
6114
6115
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6113

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


6118
6119
6120
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6118

def display_name
  @display_name
end

#effective_auto_upgrade_configGoogle::Apis::GkehubV1beta::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property effectiveAutoUpgradeConfig



6123
6124
6125
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6123

def effective_auto_upgrade_config
  @effective_auto_upgrade_config
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6128
6129
6130
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6128

def etag
  @etag
end

#ignored_clusters_selectorGoogle::Apis::GkehubV1beta::ClusterSelector

Selector for clusters. Corresponds to the JSON property ignoredClustersSelector



6133
6134
6135
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6133

def ignored_clusters_selector
  @ignored_clusters_selector
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6138
6139
6140
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6138

def labels
  @labels
end

#last_qualified_control_plane_versionString

Output only. The last qualified control plane version. Corresponds to the JSON property lastQualifiedControlPlaneVersion

Returns:

  • (String)


6143
6144
6145
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6143

def last_qualified_control_plane_version
  @last_qualified_control_plane_version
end

#last_qualified_node_versionString

Output only. The last qualified node version. Corresponds to the JSON property lastQualifiedNodeVersion

Returns:

  • (String)


6148
6149
6150
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6148

def last_qualified_node_version
  @last_qualified_node_version
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6154
6155
6156
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6154

def name
  @name
end

#operational_stateGoogle::Apis::GkehubV1beta::OperationalState

Operational state of the Rollout Sequence. Corresponds to the JSON property operationalState



6159
6160
6161
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6159

def operational_state
  @operational_state
end

#stagesArray<Google::Apis::GkehubV1beta::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages



6164
6165
6166
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6164

def stages
  @stages
end

#target_control_plane_versionString

Output only. The target control plane version of the Rollout Sequence. Corresponds to the JSON property targetControlPlaneVersion

Returns:

  • (String)


6169
6170
6171
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6169

def target_control_plane_version
  @target_control_plane_version
end

#target_node_versionString

Output only. The target node version of the Rollout Sequence. Corresponds to the JSON property targetNodeVersion

Returns:

  • (String)


6174
6175
6176
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6174

def target_node_version
  @target_node_version
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6181
6182
6183
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6181

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6186
6187
6188
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6186

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
6209
6210
6211
6212
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6193

def update!(**args)
  @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config)
  @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config)
  @etag = args[:etag] if args.key?(:etag)
  @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector)
  @labels = args[:labels] if args.key?(:labels)
  @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version)
  @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version)
  @name = args[:name] if args.key?(:name)
  @operational_state = args[:operational_state] if args.key?(:operational_state)
  @stages = args[:stages] if args.key?(:stages)
  @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version)
  @target_node_version = args[:target_node_version] if args.key?(:target_node_version)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end