Class: Google::Apis::GkehubV1beta::RolloutStage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Stage represents a single stage in the Rollout.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutStage

Returns a new instance of RolloutStage.



6255
6256
6257
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6255

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1beta::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6222
6223
6224
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6222

def cluster_selector
  @cluster_selector
end

#end_timeString

Optional. Output only. The time at which the stage ended. Corresponds to the JSON property endTime

Returns:

  • (String)


6227
6228
6229
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6227

def end_time
  @end_time
end

#fleet_projectsArray<String>

Output only. The fleet projects from the sequence that was used to create this stage. Expected format: projects/project_number Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6233
6234
6235
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6233

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Duration to soak after this stage before starting the next stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6238
6239
6240
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6238

def soak_duration
  @soak_duration
end

#stage_numberFixnum

Output only. The stage number to which this status applies. Corresponds to the JSON property stageNumber

Returns:

  • (Fixnum)


6243
6244
6245
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6243

def stage_number
  @stage_number
end

#start_timeString

Optional. Output only. The time at which the stage started. Corresponds to the JSON property startTime

Returns:

  • (String)


6248
6249
6250
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6248

def start_time
  @start_time
end

#stateString

Output only. The state of the stage. Corresponds to the JSON property state

Returns:

  • (String)


6253
6254
6255
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6253

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6260
6261
6262
6263
6264
6265
6266
6267
6268
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6260

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @end_time = args[:end_time] if args.key?(:end_time)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
  @stage_number = args[:stage_number] if args.key?(:stage_number)
  @start_time = args[:start_time] if args.key?(:start_time)
  @state = args[:state] if args.key?(:state)
end