Class: Google::Apis::GkehubV1beta::Scope

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Scope represents a Scope in a Fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Scope

Returns a new instance of Scope.



6378
6379
6380
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6378

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the scope was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6334
6335
6336
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6334

def create_time
  @create_time
end

#delete_timeString

Output only. When the scope was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6339
6340
6341
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6339

def delete_time
  @delete_time
end

#labelsHash<String,String>

Optional. Labels for this Scope. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6344
6345
6346
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6344

def labels
  @labels
end

#nameString

The resource name for the scope projects/project/locations/location/ scopes/scope` Corresponds to the JSON propertyname`

Returns:

  • (String)


6350
6351
6352
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6350

def name
  @name
end

#namespace_labelsHash<String,String>

Optional. Scope-level cluster namespace labels. For the member clusters bound to the Scope, these labels are applied to each namespace under the Scope. Scope-level labels take precedence over Namespace-level labels ( namespace_labels in the Fleet Namespace resource) if they share a key. Keys and values must be Kubernetes-conformant. Corresponds to the JSON property namespaceLabels

Returns:

  • (Hash<String,String>)


6359
6360
6361
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6359

def namespace_labels
  @namespace_labels
end

#stateGoogle::Apis::GkehubV1beta::ScopeLifecycleState

ScopeLifecycleState describes the state of a Scope resource. Corresponds to the JSON property state



6364
6365
6366
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6364

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all scope resources. If a scope resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6371
6372
6373
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6371

def uid
  @uid
end

#update_timeString

Output only. When the scope was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6376
6377
6378
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6376

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6383
6384
6385
6386
6387
6388
6389
6390
6391
6392
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6383

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end