Class: Google::Apis::GkehubV1beta::ServiceMeshCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ServiceMeshCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshCondition
constructor
A new instance of ServiceMeshCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshCondition
Returns a new instance of ServiceMeshCondition.
6499 6500 6501 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6499 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6482 6483 6484 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6482 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6487 6488 6489 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6487 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6492 6493 6494 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6492 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6497 6498 6499 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6497 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6504 6505 6506 6507 6508 6509 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6504 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |