Class: Google::Apis::GkehubV1beta::ServiceMeshMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Service Mesh: Spec for a single Membership for the servicemesh feature

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ServiceMeshMembershipSpec

Returns a new instance of ServiceMeshMembershipSpec.



6607
6608
6609
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6607

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_apiString

Optional. Specifies the API that will be used for configuring the mesh workloads. Corresponds to the JSON property configApi

Returns:

  • (String)


6594
6595
6596
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6594

def config_api
  @config_api
end

#control_planeString

Deprecated: use management instead Enables automatic control plane management. Corresponds to the JSON property controlPlane

Returns:

  • (String)


6600
6601
6602
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6600

def control_plane
  @control_plane
end

#managementString

Optional. Enables automatic Service Mesh management. Corresponds to the JSON property management

Returns:

  • (String)


6605
6606
6607
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6605

def management
  @management
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6612
6613
6614
6615
6616
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6612

def update!(**args)
  @config_api = args[:config_api] if args.key?(:config_api)
  @control_plane = args[:control_plane] if args.key?(:control_plane)
  @management = args[:management] if args.key?(:management)
end