Class: Google::Apis::GkehubV1beta::Status
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Status
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Status specifies state for the subcomponent.
Instance Attribute Summary collapse
-
#code ⇒ String
Code specifies AppDevExperienceFeature's subcomponent ready state.
-
#description ⇒ String
Description is populated if Code is Failed, explaining why it has failed.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Status
constructor
A new instance of Status.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Status
Returns a new instance of Status.
6766 6767 6768 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6766 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Code specifies AppDevExperienceFeature's subcomponent ready state.
Corresponds to the JSON property code
6759 6760 6761 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6759 def code @code end |
#description ⇒ String
Description is populated if Code is Failed, explaining why it has failed.
Corresponds to the JSON property description
6764 6765 6766 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6764 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6771 6772 6773 6774 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6771 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |