Class: Google::Apis::GkehubV1beta::WorkloadIdentityFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
WorkloadIdentity: Global feature state.
Instance Attribute Summary collapse
-
#namespace_state_details ⇒ Hash<String,Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail>
The state of the IAM namespaces for the fleet.
-
#namespace_states ⇒ Hash<String,String>
Deprecated, this field will be erased after code is changed to use the new field.
-
#scope_tenancy_workload_identity_pool ⇒ String
The full name of the scope-tenancy pool for the fleet.
-
#workload_identity_pool ⇒ String
The full name of the svc.id.goog pool for the fleet.
-
#workload_identity_pool_state_details ⇒ Hash<String,Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail>
The state of the Workload Identity Pools for the fleet.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityFeatureState
constructor
A new instance of WorkloadIdentityFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityFeatureState
Returns a new instance of WorkloadIdentityFeatureState.
6971 6972 6973 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6971 def initialize(**args) update!(**args) end |
Instance Attribute Details
#namespace_state_details ⇒ Hash<String,Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail>
The state of the IAM namespaces for the fleet.
Corresponds to the JSON property namespaceStateDetails
6948 6949 6950 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6948 def namespace_state_details @namespace_state_details end |
#namespace_states ⇒ Hash<String,String>
Deprecated, this field will be erased after code is changed to use the new
field.
Corresponds to the JSON property namespaceStates
6954 6955 6956 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6954 def namespace_states @namespace_states end |
#scope_tenancy_workload_identity_pool ⇒ String
The full name of the scope-tenancy pool for the fleet.
Corresponds to the JSON property scopeTenancyWorkloadIdentityPool
6959 6960 6961 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6959 def scope_tenancy_workload_identity_pool @scope_tenancy_workload_identity_pool end |
#workload_identity_pool ⇒ String
The full name of the svc.id.goog pool for the fleet.
Corresponds to the JSON property workloadIdentityPool
6964 6965 6966 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6964 def workload_identity_pool @workload_identity_pool end |
#workload_identity_pool_state_details ⇒ Hash<String,Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail>
The state of the Workload Identity Pools for the fleet.
Corresponds to the JSON property workloadIdentityPoolStateDetails
6969 6970 6971 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6969 def workload_identity_pool_state_details @workload_identity_pool_state_details end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6976 6977 6978 6979 6980 6981 6982 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6976 def update!(**args) @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details) @namespace_states = args[:namespace_states] if args.key?(:namespace_states) @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool) @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool) @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details) end |