Class: Google::Apis::GkehubV1beta::WorkloadIdentityIdentityProviderStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityIdentityProviderStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
IdentityProviderStateDetail represents the state of an Identity Provider.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Identity Provider.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
constructor
A new instance of WorkloadIdentityIdentityProviderStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityIdentityProviderStateDetail
Returns a new instance of WorkloadIdentityIdentityProviderStateDetail.
6859 6860 6861 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6859 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Identity Provider.
Corresponds to the JSON property code
6852 6853 6854 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6852 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
6857 6858 6859 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6857 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6864 6865 6866 6867 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6864 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |