Class: Google::Apis::GkehubV1beta::WorkloadIdentityMembershipState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityMembershipState

Returns a new instance of WorkloadIdentityMembershipState.



7017
7018
7019
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7017

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property description

Returns:

  • (String)


7010
7011
7012
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7010

def description
  @description
end

#identity_provider_state_detailsHash<String,Google::Apis::GkehubV1beta::WorkloadIdentityIdentityProviderStateDetail>

The state of the Identity Providers corresponding to the membership. Corresponds to the JSON property identityProviderStateDetails



7015
7016
7017
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7015

def identity_provider_state_details
  @identity_provider_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7022
7023
7024
7025
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7022

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @identity_provider_state_details = args[:identity_provider_state_details] if args.key?(:identity_provider_state_details)
end