Class: Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
7051 7052 7053 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7051 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
7044 7045 7046 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7044 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7049 7050 7051 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7049 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7056 7057 7058 7059 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7056 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |