Class: Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail

Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.



7142
7143
7144
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7142

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

The state of the Workload Identity Pool. Corresponds to the JSON property code

Returns:

  • (String)


7135
7136
7137
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7135

def code
  @code
end

#descriptionString

A human-readable description of the current state or returned error. Corresponds to the JSON property description

Returns:

  • (String)


7140
7141
7142
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7140

def description
  @description
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7147
7148
7149
7150
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7147

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @description = args[:description] if args.key?(:description)
end