Class: Google::Apis::GkehubV1beta::CommonFleetDefaultMemberConfigSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

CommonFleetDefaultMemberConfigSpec contains default configuration information for memberships of a fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CommonFleetDefaultMemberConfigSpec

Returns a new instance of CommonFleetDefaultMemberConfigSpec.



896
897
898
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#configmanagementGoogle::Apis::GkehubV1beta::ConfigManagementMembershipSpec

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR. Corresponds to the JSON property configmanagement



878
879
880
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 878

def configmanagement
  @configmanagement
end

#identityserviceGoogle::Apis::GkehubV1beta::IdentityServiceMembershipSpec

Anthos Identity Service: Configuration for a single Membership. Corresponds to the JSON property identityservice



883
884
885
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 883

def identityservice
  @identityservice
end

#meshGoogle::Apis::GkehubV1beta::ServiceMeshMembershipSpec

Service Mesh: Spec for a single Membership for the servicemesh feature Corresponds to the JSON property mesh



888
889
890
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 888

def mesh
  @mesh
end

#policycontrollerGoogle::Apis::GkehubV1beta::PolicyControllerMembershipSpec

Policy Controller: Configuration for a single cluster. Intended to parallel the PolicyController CR. Corresponds to the JSON property policycontroller



894
895
896
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 894

def policycontroller
  @policycontroller
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



901
902
903
904
905
906
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 901

def update!(**args)
  @configmanagement = args[:configmanagement] if args.key?(:configmanagement)
  @identityservice = args[:identityservice] if args.key?(:identityservice)
  @mesh = args[:mesh] if args.key?(:mesh)
  @policycontroller = args[:policycontroller] if args.key?(:policycontroller)
end