Class: Google::Apis::GkehubV1beta::ConfigManagementConfigSync
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConfigManagementConfigSync
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Configuration for Config Sync
Instance Attribute Summary collapse
-
#deployment_overrides ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementDeploymentOverride>
Optional.
-
#enabled ⇒ Boolean
(also: #enabled?)
Optional.
-
#git ⇒ Google::Apis::GkehubV1beta::ConfigManagementGitConfig
Git repo configuration for a single cluster.
-
#metrics_gcp_service_account_email ⇒ String
Optional.
-
#oci ⇒ Google::Apis::GkehubV1beta::ConfigManagementOciConfig
OCI repo configuration for a single cluster Corresponds to the JSON property
oci. -
#prevent_drift ⇒ Boolean
(also: #prevent_drift?)
Optional.
-
#source_format ⇒ String
Optional.
-
#stop_syncing ⇒ Boolean
(also: #stop_syncing?)
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementConfigSync
constructor
A new instance of ConfigManagementConfigSync.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementConfigSync
Returns a new instance of ConfigManagementConfigSync.
1091 1092 1093 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1091 def initialize(**args) update!(**args) end |
Instance Attribute Details
#deployment_overrides ⇒ Array<Google::Apis::GkehubV1beta::ConfigManagementDeploymentOverride>
Optional. Configuration for deployment overrides. Applies only to Config Sync
deployments with containers that are not a root or namespace reconciler:
reconciler-manager, otel-collector, resource-group-controller-manager,
admission-webhook. To override a root or namespace reconciler, use the
rootsync or reposync fields at https://docs.cloud.google.com/kubernetes-engine/
config-sync/docs/reference/rootsync-reposync-fields#override-resources instead.
Corresponds to the JSON property deploymentOverrides
1032 1033 1034 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1032 def deployment_overrides @deployment_overrides end |
#enabled ⇒ Boolean Also known as: enabled?
Optional. Enables the installation of Config Sync. If set to true, the Feature
will manage Config Sync resources, and apply the other ConfigSync fields if
they exist. If set to false, the Feature will ignore all other ConfigSync
fields and delete the Config Sync resources. If omitted, ConfigSync is
considered enabled if the git or oci field is present.
Corresponds to the JSON property enabled
1041 1042 1043 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1041 def enabled @enabled end |
#git ⇒ Google::Apis::GkehubV1beta::ConfigManagementGitConfig
Git repo configuration for a single cluster.
Corresponds to the JSON property git
1047 1048 1049 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1047 def git @git end |
#metrics_gcp_service_account_email ⇒ String
Optional. The Email of the Google Cloud Service Account (GSA) used for
exporting Config Sync metrics to Cloud Monitoring and Cloud Monarch when
Workload Identity is enabled. The GSA should have the Monitoring Metric Writer
(roles/monitoring.metricWriter) IAM role. The Kubernetes ServiceAccount
default in the namespace config-management-monitoring should be bound to
the GSA. Deprecated: If Workload Identity Federation for GKE is enabled,
Google Cloud Service Account is no longer needed for exporting Config Sync
metrics: https://cloud.google.com/kubernetes-engine/enterprise/config-sync/
docs/how-to/monitor-config-sync-cloud-monitoring#custom-monitoring.
Corresponds to the JSON property metricsGcpServiceAccountEmail
1060 1061 1062 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1060 def metrics_gcp_service_account_email @metrics_gcp_service_account_email end |
#oci ⇒ Google::Apis::GkehubV1beta::ConfigManagementOciConfig
OCI repo configuration for a single cluster
Corresponds to the JSON property oci
1065 1066 1067 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1065 def oci @oci end |
#prevent_drift ⇒ Boolean Also known as: prevent_drift?
Optional. Set to true to enable the Config Sync admission webhook to prevent
drifts. If set to false, disables the Config Sync admission webhook and does
not prevent drifts. Defaults to false. See https://docs.cloud.google.com/
kubernetes-engine/config-sync/docs/how-to/prevent-config-drift for details.
Corresponds to the JSON property preventDrift
1073 1074 1075 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1073 def prevent_drift @prevent_drift end |
#source_format ⇒ String
Optional. Specifies whether the Config Sync repo is in hierarchical or
unstructured mode. Defaults to hierarchical. See https://docs.cloud.google.
com/kubernetes-engine/config-sync/docs/concepts/configs#organize-configs for
an explanation.
Corresponds to the JSON property sourceFormat
1082 1083 1084 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1082 def source_format @source_format end |
#stop_syncing ⇒ Boolean Also known as: stop_syncing?
Optional. Set to true to stop syncing configs for a single cluster. Default to
false.
Corresponds to the JSON property stopSyncing
1088 1089 1090 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1088 def stop_syncing @stop_syncing end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1096 1097 1098 1099 1100 1101 1102 1103 1104 1105 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1096 def update!(**args) @deployment_overrides = args[:deployment_overrides] if args.key?(:deployment_overrides) @enabled = args[:enabled] if args.key?(:enabled) @git = args[:git] if args.key?(:git) @metrics_gcp_service_account_email = args[:metrics_gcp_service_account_email] if args.key?(:metrics_gcp_service_account_email) @oci = args[:oci] if args.key?(:oci) @prevent_drift = args[:prevent_drift] if args.key?(:prevent_drift) @source_format = args[:source_format] if args.key?(:source_format) @stop_syncing = args[:stop_syncing] if args.key?(:stop_syncing) end |