Class: Google::Apis::GkehubV1beta::ConfigManagementConfigSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

State information for ConfigSync

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementConfigSyncState

Returns a new instance of ConfigManagementConfigSyncState.



1171
1172
1173
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1171

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_level_stop_syncing_stateString

Output only. Whether syncing resources to the cluster is stopped at the cluster level. Corresponds to the JSON property clusterLevelStopSyncingState

Returns:

  • (String)


1128
1129
1130
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1128

def cluster_level_stop_syncing_state
  @cluster_level_stop_syncing_state
end

#cr_countFixnum

Output only. The number of RootSync and RepoSync CRs in the cluster. Corresponds to the JSON property crCount

Returns:

  • (Fixnum)


1133
1134
1135
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1133

def cr_count
  @cr_count
end

#deployment_stateGoogle::Apis::GkehubV1beta::ConfigManagementConfigSyncDeploymentState

The state of ConfigSync's deployment on a cluster Corresponds to the JSON property deploymentState



1138
1139
1140
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1138

def deployment_state
  @deployment_state
end

#errorsArray<Google::Apis::GkehubV1beta::ConfigManagementConfigSyncError>

Output only. Errors pertaining to the installation of Config Sync. Corresponds to the JSON property errors



1143
1144
1145
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1143

def errors
  @errors
end

#reposync_crdString

Output only. The state of the Reposync CRD Corresponds to the JSON property reposyncCrd

Returns:

  • (String)


1148
1149
1150
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1148

def reposync_crd
  @reposync_crd
end

#rootsync_crdString

Output only. The state of the RootSync CRD Corresponds to the JSON property rootsyncCrd

Returns:

  • (String)


1153
1154
1155
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1153

def rootsync_crd
  @rootsync_crd
end

#stateString

Output only. The state of CS This field summarizes the other fields in this message. Corresponds to the JSON property state

Returns:

  • (String)


1159
1160
1161
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1159

def state
  @state
end

#sync_stateGoogle::Apis::GkehubV1beta::ConfigManagementSyncState

State indicating an ACM's progress syncing configurations to a cluster Corresponds to the JSON property syncState



1164
1165
1166
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1164

def sync_state
  @sync_state
end

#versionGoogle::Apis::GkehubV1beta::ConfigManagementConfigSyncVersion

Specific versioning information pertaining to ConfigSync's Pods Corresponds to the JSON property version



1169
1170
1171
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1169

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1176
1177
1178
1179
1180
1181
1182
1183
1184
1185
1186
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1176

def update!(**args)
  @cluster_level_stop_syncing_state = args[:cluster_level_stop_syncing_state] if args.key?(:cluster_level_stop_syncing_state)
  @cr_count = args[:cr_count] if args.key?(:cr_count)
  @deployment_state = args[:deployment_state] if args.key?(:deployment_state)
  @errors = args[:errors] if args.key?(:errors)
  @reposync_crd = args[:reposync_crd] if args.key?(:reposync_crd)
  @rootsync_crd = args[:rootsync_crd] if args.key?(:rootsync_crd)
  @state = args[:state] if args.key?(:state)
  @sync_state = args[:sync_state] if args.key?(:sync_state)
  @version = args[:version] if args.key?(:version)
end