Class: Google::Apis::GkehubV1beta::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1755
1756
1757
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1755

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV1beta::ConfigManagementBinauthzConfig

Configuration for Binauthz Corresponds to the JSON property binauthz



1713
1714
1715
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1713

def binauthz
  @binauthz
end

#clusterString

Optional. User-specified cluster name used by the Config Sync cluster-name- selector annotation or ClusterSelector object, for applying configs to only a subset of clusters. Read more about the cluster-name-selector annotation and ClusterSelector object at https://docs.cloud.google.com/kubernetes-engine/ config-sync/docs/how-to/cluster-scoped-objects#limiting-configs. Only set this field if a name different from the cluster's fleet membership name is used by the Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1724
1725
1726
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1724

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1beta::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1729
1730
1731
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1729

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1734
1735
1736
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1734

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Deprecated: From version 1.21.0, automatic Feature management is unavailable, and Config Sync only supports manual upgrades. Corresponds to the JSON property management

Returns:

  • (String)


1740
1741
1742
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1740

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1745
1746
1747
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1745

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of Config Sync to install. Defaults to the latest supported Config Sync version if the config_sync field is enabled. See supported versions at https://cloud.google.com/kubernetes-engine/config-sync/docs/get- support-config-sync#version_support_policy. Corresponds to the JSON property version

Returns:

  • (String)


1753
1754
1755
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1753

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1760
1761
1762
1763
1764
1765
1766
1767
1768
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1760

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end