Class: Google::Apis::GkehubV1beta::ConfigManagementMembershipSpec

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Anthos Config Management: Configuration for a single cluster. Intended to parallel the ConfigManagement CR.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementMembershipSpec

Returns a new instance of ConfigManagementMembershipSpec.



1668
1669
1670
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1668

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binauthzGoogle::Apis::GkehubV1beta::ConfigManagementBinauthzConfig

Configuration for Binauthz Corresponds to the JSON property binauthz



1631
1632
1633
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1631

def binauthz
  @binauthz
end

#clusterString

Optional. The user-specified cluster name used by Config Sync cluster-name- selector annotation or ClusterSelector, for applying configs to only a subset of clusters. Omit this field if the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Set this field if a name different from the cluster's fleet membership name is used by Config Sync cluster-name-selector annotation or ClusterSelector. Corresponds to the JSON property cluster

Returns:

  • (String)


1641
1642
1643
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1641

def cluster
  @cluster
end

#config_syncGoogle::Apis::GkehubV1beta::ConfigManagementConfigSync

Configuration for Config Sync Corresponds to the JSON property configSync



1646
1647
1648
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1646

def config_sync
  @config_sync
end

#hierarchy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementHierarchyControllerConfig

Configuration for Hierarchy Controller Corresponds to the JSON property hierarchyController



1651
1652
1653
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1651

def hierarchy_controller
  @hierarchy_controller
end

#managementString

Optional. Enables automatic Feature management. Corresponds to the JSON property management

Returns:

  • (String)


1656
1657
1658
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1656

def management
  @management
end

#policy_controllerGoogle::Apis::GkehubV1beta::ConfigManagementPolicyController

Configuration for Policy Controller Corresponds to the JSON property policyController



1661
1662
1663
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1661

def policy_controller
  @policy_controller
end

#versionString

Optional. Version of ACM installed. Corresponds to the JSON property version

Returns:

  • (String)


1666
1667
1668
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1666

def version
  @version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1673
1674
1675
1676
1677
1678
1679
1680
1681
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1673

def update!(**args)
  @binauthz = args[:binauthz] if args.key?(:binauthz)
  @cluster = args[:cluster] if args.key?(:cluster)
  @config_sync = args[:config_sync] if args.key?(:config_sync)
  @hierarchy_controller = args[:hierarchy_controller] if args.key?(:hierarchy_controller)
  @management = args[:management] if args.key?(:management)
  @policy_controller = args[:policy_controller] if args.key?(:policy_controller)
  @version = args[:version] if args.key?(:version)
end