Class: Google::Apis::GkehubV1beta::ConfigManagementOciConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ConfigManagementOciConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
OCI repo configuration for a single cluster
Instance Attribute Summary collapse
-
#gcp_service_account_email ⇒ String
Optional.
-
#policy_dir ⇒ String
Optional.
-
#secret_type ⇒ String
Required.
-
#sync_repo ⇒ String
Required.
-
#sync_wait_secs ⇒ Fixnum
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ConfigManagementOciConfig
constructor
A new instance of ConfigManagementOciConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ConfigManagementOciConfig
Returns a new instance of ConfigManagementOciConfig.
1869 1870 1871 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1869 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gcp_service_account_email ⇒ String
Optional. The Google Cloud Service Account Email used for auth when
secret_type is gcpserviceaccount.
Corresponds to the JSON property gcpServiceAccountEmail
1843 1844 1845 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1843 def gcp_service_account_email @gcp_service_account_email end |
#policy_dir ⇒ String
Optional. The absolute path of the directory that contains the local resources.
Default: the root directory of the image.
Corresponds to the JSON property policyDir
1849 1850 1851 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1849 def policy_dir @policy_dir end |
#secret_type ⇒ String
Required. Type of secret configured for access to the OCI repo. Must be one of
gcenode, gcpserviceaccount, k8sserviceaccount or none. The validation
of this is case-sensitive.
Corresponds to the JSON property secretType
1856 1857 1858 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1856 def secret_type @secret_type end |
#sync_repo ⇒ String
Required. The OCI image repository URL for the package to sync from. e.g.
LOCATION-docker.pkg.dev/PROJECT_ID/REPOSITORY_NAME/PACKAGE_NAME.
Corresponds to the JSON property syncRepo
1862 1863 1864 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1862 def sync_repo @sync_repo end |
#sync_wait_secs ⇒ Fixnum
Optional. Period in seconds between consecutive syncs. Default: 15.
Corresponds to the JSON property syncWaitSecs
1867 1868 1869 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1867 def sync_wait_secs @sync_wait_secs end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1874 1875 1876 1877 1878 1879 1880 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 1874 def update!(**args) @gcp_service_account_email = args[:gcp_service_account_email] if args.key?(:gcp_service_account_email) @policy_dir = args[:policy_dir] if args.key?(:policy_dir) @secret_type = args[:secret_type] if args.key?(:secret_type) @sync_repo = args[:sync_repo] if args.key?(:sync_repo) @sync_wait_secs = args[:sync_wait_secs] if args.key?(:sync_wait_secs) end |