Class: Google::Apis::GkehubV1beta::ConfigManagementSyncError

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

An ACM created error representing a problem syncing configurations

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncError

Returns a new instance of ConfigManagementSyncError.



2124
2125
2126
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2124

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

An ACM defined error code Corresponds to the JSON property code

Returns:

  • (String)


2112
2113
2114
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2112

def code
  @code
end

#error_messageString

A description of the error Corresponds to the JSON property errorMessage

Returns:

  • (String)


2117
2118
2119
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2117

def error_message
  @error_message
end

#error_resourcesArray<Google::Apis::GkehubV1beta::ConfigManagementErrorResource>

A list of config(s) associated with the error, if any Corresponds to the JSON property errorResources



2122
2123
2124
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2122

def error_resources
  @error_resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2129
2130
2131
2132
2133
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2129

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @error_message = args[:error_message] if args.key?(:error_message)
  @error_resources = args[:error_resources] if args.key?(:error_resources)
end