Class: Google::Apis::GkehubV1beta::ConfigManagementSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

State indicating an ACM's progress syncing configurations to a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncState

Returns a new instance of ConfigManagementSyncState.



2165
2166
2167
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2165

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Sync status code Corresponds to the JSON property code

Returns:

  • (String)


2129
2130
2131
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2129

def code
  @code
end

#errorsArray<Google::Apis::GkehubV1beta::ConfigManagementSyncError>

A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist. Corresponds to the JSON property errors



2136
2137
2138
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2136

def errors
  @errors
end

#import_tokenString

Token indicating the state of the importer. Corresponds to the JSON property importToken

Returns:

  • (String)


2141
2142
2143
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2141

def import_token
  @import_token
end

#last_syncString

Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang. org/pkg/time/#Time.String Corresponds to the JSON property lastSync

Returns:

  • (String)


2148
2149
2150
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2148

def last_sync
  @last_sync
end

#last_sync_timeString

Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2153
2154
2155
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2153

def last_sync_time
  @last_sync_time
end

#source_tokenString

Token indicating the state of the repo. Corresponds to the JSON property sourceToken

Returns:

  • (String)


2158
2159
2160
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2158

def source_token
  @source_token
end

#sync_tokenString

Token indicating the state of the syncer. Corresponds to the JSON property syncToken

Returns:

  • (String)


2163
2164
2165
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2163

def sync_token
  @sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2170
2171
2172
2173
2174
2175
2176
2177
2178
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2170

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @errors = args[:errors] if args.key?(:errors)
  @import_token = args[:import_token] if args.key?(:import_token)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @source_token = args[:source_token] if args.key?(:source_token)
  @sync_token = args[:sync_token] if args.key?(:sync_token)
end