Class: Google::Apis::GkehubV1beta::ConfigManagementSyncState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

State indicating an ACM's progress syncing configurations to a cluster

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ConfigManagementSyncState

Returns a new instance of ConfigManagementSyncState.



2078
2079
2080
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2078

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#codeString

Sync status code Corresponds to the JSON property code

Returns:

  • (String)


2042
2043
2044
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2042

def code
  @code
end

#errorsArray<Google::Apis::GkehubV1beta::ConfigManagementSyncError>

A list of errors resulting from problematic configs. This list will be truncated after 100 errors, although it is unlikely for that many errors to simultaneously exist. Corresponds to the JSON property errors



2049
2050
2051
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2049

def errors
  @errors
end

#import_tokenString

Token indicating the state of the importer. Corresponds to the JSON property importToken

Returns:

  • (String)


2054
2055
2056
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2054

def import_token
  @import_token
end

#last_syncString

Deprecated: use last_sync_time instead. Timestamp of when ACM last successfully synced the repo The time format is specified in https://golang. org/pkg/time/#Time.String Corresponds to the JSON property lastSync

Returns:

  • (String)


2061
2062
2063
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2061

def last_sync
  @last_sync
end

#last_sync_timeString

Timestamp type of when ACM last successfully synced the repo Corresponds to the JSON property lastSyncTime

Returns:

  • (String)


2066
2067
2068
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2066

def last_sync_time
  @last_sync_time
end

#source_tokenString

Token indicating the state of the repo. Corresponds to the JSON property sourceToken

Returns:

  • (String)


2071
2072
2073
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2071

def source_token
  @source_token
end

#sync_tokenString

Token indicating the state of the syncer. Corresponds to the JSON property syncToken

Returns:

  • (String)


2076
2077
2078
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2076

def sync_token
  @sync_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2083
2084
2085
2086
2087
2088
2089
2090
2091
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2083

def update!(**args)
  @code = args[:code] if args.key?(:code)
  @errors = args[:errors] if args.key?(:errors)
  @import_token = args[:import_token] if args.key?(:import_token)
  @last_sync = args[:last_sync] if args.key?(:last_sync)
  @last_sync_time = args[:last_sync_time] if args.key?(:last_sync_time)
  @source_token = args[:source_token] if args.key?(:source_token)
  @sync_token = args[:sync_token] if args.key?(:sync_token)
end