Class: Google::Apis::GkehubV1beta::DefaultClusterConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

DefaultClusterConfig describes the default cluster configurations to be applied to all clusters born-in-fleet.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DefaultClusterConfig

Returns a new instance of DefaultClusterConfig.



2267
2268
2269
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2267

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#binary_authorization_configGoogle::Apis::GkehubV1beta::BinaryAuthorizationConfig

BinaryAuthorizationConfig defines the fleet level configuration of binary authorization feature. Corresponds to the JSON property binaryAuthorizationConfig



2251
2252
2253
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2251

def binary_authorization_config
  @binary_authorization_config
end

#compliance_posture_configGoogle::Apis::GkehubV1beta::CompliancePostureConfig

Deprecated: Compliance Posture is no longer supported. For more details, see https://cloud.google.com/kubernetes-engine/docs/deprecations/posture- management-deprecation. CompliancePostureConfig defines the settings needed to enable/disable features for the Compliance Posture. Corresponds to the JSON property compliancePostureConfig



2259
2260
2261
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2259

def compliance_posture_config
  @compliance_posture_config
end

#security_posture_configGoogle::Apis::GkehubV1beta::SecurityPostureConfig

SecurityPostureConfig defines the flags needed to enable/disable features for the Security Posture API. Corresponds to the JSON property securityPostureConfig



2265
2266
2267
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2265

def security_posture_config
  @security_posture_config
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2272
2273
2274
2275
2276
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2272

def update!(**args)
  @binary_authorization_config = args[:binary_authorization_config] if args.key?(:binary_authorization_config)
  @compliance_posture_config = args[:compliance_posture_config] if args.key?(:compliance_posture_config)
  @security_posture_config = args[:security_posture_config] if args.key?(:security_posture_config)
end