Class: Google::Apis::GkehubV1beta::Feature

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Feature represents the settings and status of any Fleet Feature.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Feature

Returns a new instance of Feature.



2477
2478
2479
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2477

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the Feature resource was created. Corresponds to the JSON property createTime

Returns:

  • (String)


2377
2378
2379
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2377

def create_time
  @create_time
end

#delete_timeString

Output only. When the Feature resource was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


2382
2383
2384
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2382

def delete_time
  @delete_time
end

#fleet_default_member_configGoogle::Apis::GkehubV1beta::CommonFleetDefaultMemberConfigSpec

CommonFleetDefaultMemberConfigSpec contains default configuration information for memberships of a fleet Corresponds to the JSON property fleetDefaultMemberConfig



2388
2389
2390
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2388

def fleet_default_member_config
  @fleet_default_member_config
end

#labelsHash<String,String>

Labels for this Feature. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


2393
2394
2395
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2393

def labels
  @labels
end

#membership_specsHash<String,Google::Apis::GkehubV1beta::MembershipFeatureSpec>

Optional. Membership-specific configuration for this Feature. If this Feature does not support any per-Membership configuration, this field may be unused. The keys indicate which Membership the configuration is for, in the form: projects/p/locations/l/memberships/m`Wherepis the project,lis a valid location andmis a valid Membership in this project at that location. pWILL match the Feature's project.pwill always be returned as the project number, but the project ID is also accepted during input. If the same Membership is specified in the map twice (using the project ID form, and the project number form), exactly ONE of the entries will be saved, with no guarantees as to which. For this reason, it is recommended the same format be used for all entries when mutating a Feature. Corresponds to the JSON propertymembershipSpecs`



2408
2409
2410
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2408

def membership_specs
  @membership_specs
end

#membership_statesHash<String,Google::Apis::GkehubV1beta::MembershipFeatureState>

Output only. Membership-specific Feature status. If this Feature does report any per-Membership status, this field may be unused. The keys indicate which Membership the state is for, in the form: projects/p/locations/l/ memberships/m`Wherepis the project number,lis a valid location and mis a valid Membership in this project at that location.pMUST match the Feature's project number. Corresponds to the JSON propertymembershipStates`



2418
2419
2420
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2418

def membership_states
  @membership_states
end

#nameString

Output only. The full, unique name of this Feature resource in the format projects/*/locations/*/features/*. Corresponds to the JSON property name

Returns:

  • (String)


2424
2425
2426
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2424

def name
  @name
end

#resource_stateGoogle::Apis::GkehubV1beta::FeatureResourceState

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships. Corresponds to the JSON property resourceState



2431
2432
2433
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2431

def resource_state
  @resource_state
end

#scope_specsHash<String,Google::Apis::GkehubV1beta::ScopeFeatureSpec>

Optional. Scope-specific configuration for this Feature. If this Feature does not support any per-Scope configuration, this field may be unused. The keys indicate which Scope the configuration is for, in the form: projects/p/ locations/global/scopes/s`Wherepis the project,sis a valid Scope in this project.pWILL match the Feature's project.pwill always be returned as the project number, but the project ID is also accepted during input. If the same Scope is specified in the map twice (using the project ID form, and the project number form), exactly ONE of the entries will be saved, with no guarantees as to which. For this reason, it is recommended the same format be used for all entries when mutating a Feature. Corresponds to the JSON propertyscopeSpecs`



2445
2446
2447
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2445

def scope_specs
  @scope_specs
end

#scope_statesHash<String,Google::Apis::GkehubV1beta::ScopeFeatureState>

Output only. Scope-specific Feature status. If this Feature does report any per-Scope status, this field may be unused. The keys indicate which Scope the state is for, in the form: projects/p/locations/global/scopes/s`Wherep is the project,sis a valid Scope in this project.pWILL match the Feature's project. Corresponds to the JSON propertyscopeStates`



2454
2455
2456
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2454

def scope_states
  @scope_states
end

#specGoogle::Apis::GkehubV1beta::CommonFeatureSpec

CommonFeatureSpec contains Fleet-wide configuration information Corresponds to the JSON property spec



2459
2460
2461
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2459

def spec
  @spec
end

#stateGoogle::Apis::GkehubV1beta::CommonFeatureState

CommonFeatureState contains Fleet-wide Feature status information. Corresponds to the JSON property state



2464
2465
2466
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2464

def state
  @state
end

#unreachableArray<String>

Output only. List of locations that could not be reached while fetching this feature. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


2470
2471
2472
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2470

def unreachable
  @unreachable
end

#update_timeString

Output only. When the Feature resource was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


2475
2476
2477
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2475

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2482
2483
2484
2485
2486
2487
2488
2489
2490
2491
2492
2493
2494
2495
2496
2497
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2482

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @fleet_default_member_config = args[:fleet_default_member_config] if args.key?(:fleet_default_member_config)
  @labels = args[:labels] if args.key?(:labels)
  @membership_specs = args[:membership_specs] if args.key?(:membership_specs)
  @membership_states = args[:membership_states] if args.key?(:membership_states)
  @name = args[:name] if args.key?(:name)
  @resource_state = args[:resource_state] if args.key?(:resource_state)
  @scope_specs = args[:scope_specs] if args.key?(:scope_specs)
  @scope_states = args[:scope_states] if args.key?(:scope_states)
  @spec = args[:spec] if args.key?(:spec)
  @state = args[:state] if args.key?(:state)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
  @update_time = args[:update_time] if args.key?(:update_time)
end