Class: Google::Apis::GkehubV1beta::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2497
2498
2499
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2497

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2495
2496
2497
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2495

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2502
2503
2504
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2502

def update!(**args)
  @state = args[:state] if args.key?(:state)
end