Class: Google::Apis::GkehubV1beta::FeatureResourceState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

FeatureResourceState describes the state of a Feature resource in the GkeHub API. See FeatureState for the "running state" of the Feature in the Fleet and across Memberships.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FeatureResourceState

Returns a new instance of FeatureResourceState.



2408
2409
2410
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2408

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#stateString

The current state of the Feature resource in the Hub API. Corresponds to the JSON property state

Returns:

  • (String)


2406
2407
2408
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2406

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2413
2414
2415
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 2413

def update!(**args)
  @state = args[:state] if args.key?(:state)
end