Class: Google::Apis::GkehubV1beta::IdentityServiceLdapConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::IdentityServiceLdapConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Configuration for the LDAP Auth flow.
Instance Attribute Summary collapse
-
#group ⇒ Google::Apis::GkehubV1beta::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the directory.
-
#server ⇒ Google::Apis::GkehubV1beta::IdentityServiceServerConfig
Server settings for the external LDAP server.
-
#service_account ⇒ Google::Apis::GkehubV1beta::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform the LDAP search in the directory.
-
#user ⇒ Google::Apis::GkehubV1beta::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceLdapConfig
constructor
A new instance of IdentityServiceLdapConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceLdapConfig
Returns a new instance of IdentityServiceLdapConfig.
3224 3225 3226 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3224 def initialize(**args) update!(**args) end |
Instance Attribute Details
#group ⇒ Google::Apis::GkehubV1beta::IdentityServiceGroupConfig
Contains the properties for locating and authenticating groups in the
directory.
Corresponds to the JSON property group
3205 3206 3207 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3205 def group @group end |
#server ⇒ Google::Apis::GkehubV1beta::IdentityServiceServerConfig
Server settings for the external LDAP server.
Corresponds to the JSON property server
3210 3211 3212 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3210 def server @server end |
#service_account ⇒ Google::Apis::GkehubV1beta::IdentityServiceServiceAccountConfig
Contains the credentials of the service account which is authorized to perform
the LDAP search in the directory. The credentials can be supplied by the
combination of the DN and password or the client certificate.
Corresponds to the JSON property serviceAccount
3217 3218 3219 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3217 def service_account @service_account end |
#user ⇒ Google::Apis::GkehubV1beta::IdentityServiceUserConfig
Defines where users exist in the LDAP directory.
Corresponds to the JSON property user
3222 3223 3224 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3222 def user @user end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3229 3230 3231 3232 3233 3234 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3229 def update!(**args) @group = args[:group] if args.key?(:group) @server = args[:server] if args.key?(:server) @service_account = args[:service_account] if args.key?(:service_account) @user = args[:user] if args.key?(:user) end |