Class: Google::Apis::GkehubV1beta::IdentityServiceLdapConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Configuration for the LDAP Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceLdapConfig

Returns a new instance of IdentityServiceLdapConfig.



3116
3117
3118
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3116

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#groupGoogle::Apis::GkehubV1beta::IdentityServiceGroupConfig

Contains the properties for locating and authenticating groups in the directory. Corresponds to the JSON property group



3097
3098
3099
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3097

def group
  @group
end

#serverGoogle::Apis::GkehubV1beta::IdentityServiceServerConfig

Server settings for the external LDAP server. Corresponds to the JSON property server



3102
3103
3104
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3102

def server
  @server
end

#service_accountGoogle::Apis::GkehubV1beta::IdentityServiceServiceAccountConfig

Contains the credentials of the service account which is authorized to perform the LDAP search in the directory. The credentials can be supplied by the combination of the DN and password or the client certificate. Corresponds to the JSON property serviceAccount



3109
3110
3111
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3109

def 
  @service_account
end

#userGoogle::Apis::GkehubV1beta::IdentityServiceUserConfig

Defines where users exist in the LDAP directory. Corresponds to the JSON property user



3114
3115
3116
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3114

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3121
3122
3123
3124
3125
3126
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3121

def update!(**args)
  @group = args[:group] if args.key?(:group)
  @server = args[:server] if args.key?(:server)
  @service_account = args[:service_account] if args.key?(:service_account)
  @user = args[:user] if args.key?(:user)
end