Class: Google::Apis::GkehubV1beta::IdentityServiceOidcConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Configuration for OIDC Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceOidcConfig

Returns a new instance of IdentityServiceOidcConfig.



3397
3398
3399
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3397

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#certificate_authority_dataString

PEM-encoded CA for OIDC provider. Corresponds to the JSON property certificateAuthorityData

Returns:

  • (String)


3324
3325
3326
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3324

def certificate_authority_data
  @certificate_authority_data
end

#client_idString

ID for OIDC client application. Corresponds to the JSON property clientId

Returns:

  • (String)


3329
3330
3331
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3329

def client_id
  @client_id
end

#client_secretString

Input only. Unencrypted OIDC client secret will be passed to the GKE Hub CLH. Corresponds to the JSON property clientSecret

Returns:

  • (String)


3334
3335
3336
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3334

def client_secret
  @client_secret
end

#deploy_cloud_console_proxyBoolean Also known as: deploy_cloud_console_proxy?

Flag to denote if reverse proxy is used to connect to auth provider. This flag should be set to true when provider is not reachable by Google Cloud Console. Corresponds to the JSON property deployCloudConsoleProxy

Returns:

  • (Boolean)


3340
3341
3342
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3340

def deploy_cloud_console_proxy
  @deploy_cloud_console_proxy
end

#enable_access_tokenBoolean Also known as: enable_access_token?

Enable access token. Corresponds to the JSON property enableAccessToken

Returns:

  • (Boolean)


3346
3347
3348
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3346

def enable_access_token
  @enable_access_token
end

#encrypted_client_secretString

Output only. Encrypted OIDC Client secret Corresponds to the JSON property encryptedClientSecret NOTE: Values are automatically base64 encoded/decoded in the client library.

Returns:

  • (String)


3353
3354
3355
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3353

def encrypted_client_secret
  @encrypted_client_secret
end

#extra_paramsString

Comma-separated list of key-value pairs. Corresponds to the JSON property extraParams

Returns:

  • (String)


3358
3359
3360
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3358

def extra_params
  @extra_params
end

#group_prefixString

Prefix to prepend to group name. Corresponds to the JSON property groupPrefix

Returns:

  • (String)


3363
3364
3365
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3363

def group_prefix
  @group_prefix
end

#groups_claimString

Claim in OIDC ID token that holds group information. Corresponds to the JSON property groupsClaim

Returns:

  • (String)


3368
3369
3370
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3368

def groups_claim
  @groups_claim
end

#issuer_uriString

URI for the OIDC provider. This should point to the level below .well-known/ openid-configuration. Corresponds to the JSON property issuerUri

Returns:

  • (String)


3374
3375
3376
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3374

def issuer_uri
  @issuer_uri
end

#kubectl_redirect_uriString

Registered redirect uri to redirect users going through OAuth flow using kubectl plugin. Corresponds to the JSON property kubectlRedirectUri

Returns:

  • (String)


3380
3381
3382
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3380

def kubectl_redirect_uri
  @kubectl_redirect_uri
end

#scopesString

Comma-separated list of identifiers. Corresponds to the JSON property scopes

Returns:

  • (String)


3385
3386
3387
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3385

def scopes
  @scopes
end

#user_claimString

Claim in OIDC ID token that holds username. Corresponds to the JSON property userClaim

Returns:

  • (String)


3390
3391
3392
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3390

def user_claim
  @user_claim
end

#user_prefixString

Prefix to prepend to user name. Corresponds to the JSON property userPrefix

Returns:

  • (String)


3395
3396
3397
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3395

def user_prefix
  @user_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3402
3403
3404
3405
3406
3407
3408
3409
3410
3411
3412
3413
3414
3415
3416
3417
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3402

def update!(**args)
  @certificate_authority_data = args[:certificate_authority_data] if args.key?(:certificate_authority_data)
  @client_id = args[:client_id] if args.key?(:client_id)
  @client_secret = args[:client_secret] if args.key?(:client_secret)
  @deploy_cloud_console_proxy = args[:deploy_cloud_console_proxy] if args.key?(:deploy_cloud_console_proxy)
  @enable_access_token = args[:enable_access_token] if args.key?(:enable_access_token)
  @encrypted_client_secret = args[:encrypted_client_secret] if args.key?(:encrypted_client_secret)
  @extra_params = args[:extra_params] if args.key?(:extra_params)
  @group_prefix = args[:group_prefix] if args.key?(:group_prefix)
  @groups_claim = args[:groups_claim] if args.key?(:groups_claim)
  @issuer_uri = args[:issuer_uri] if args.key?(:issuer_uri)
  @kubectl_redirect_uri = args[:kubectl_redirect_uri] if args.key?(:kubectl_redirect_uri)
  @scopes = args[:scopes] if args.key?(:scopes)
  @user_claim = args[:user_claim] if args.key?(:user_claim)
  @user_prefix = args[:user_prefix] if args.key?(:user_prefix)
end