Class: Google::Apis::GkehubV1beta::IdentityServiceSamlConfig
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::IdentityServiceSamlConfig
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Configuration for the SAML Auth flow.
Instance Attribute Summary collapse
-
#attribute_mapping ⇒ Hash<String,String>
Optional.
-
#group_prefix ⇒ String
Optional.
-
#groups_attribute ⇒ String
Optional.
-
#identity_provider_certificates ⇒ Array<String>
Required.
-
#identity_provider_id ⇒ String
Required.
-
#identity_provider_sso_uri ⇒ String
Required.
-
#user_attribute ⇒ String
Optional.
-
#user_prefix ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ IdentityServiceSamlConfig
constructor
A new instance of IdentityServiceSamlConfig.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ IdentityServiceSamlConfig
Returns a new instance of IdentityServiceSamlConfig.
3470 3471 3472 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3470 def initialize(**args) update!(**args) end |
Instance Attribute Details
#attribute_mapping ⇒ Hash<String,String>
Optional. The mapping of additional user attributes like nickname, birthday
and address etc.. key is the name of this additional attribute. value is a
string presenting as CEL(common expression language, go/cel) used for getting
the value from the resources. Take nickname as an example, in this case, key
is "attribute.nickname" and value is "assertion.nickname".
Corresponds to the JSON property attributeMapping
3428 3429 3430 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3428 def attribute_mapping @attribute_mapping end |
#group_prefix ⇒ String
Optional. Prefix to prepend to group name.
Corresponds to the JSON property groupPrefix
3433 3434 3435 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3433 def group_prefix @group_prefix end |
#groups_attribute ⇒ String
Optional. The SAML attribute to read groups from. This value is expected to be
a string and will be passed along as-is (with the option of being prefixed by
the group_prefix).
Corresponds to the JSON property groupsAttribute
3440 3441 3442 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3440 def groups_attribute @groups_attribute end |
#identity_provider_certificates ⇒ Array<String>
Required. The list of IdP certificates to validate the SAML response against.
Corresponds to the JSON property identityProviderCertificates
3445 3446 3447 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3445 def identity_provider_certificates @identity_provider_certificates end |
#identity_provider_id ⇒ String
Required. The entity ID of the SAML IdP.
Corresponds to the JSON property identityProviderId
3450 3451 3452 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3450 def identity_provider_id @identity_provider_id end |
#identity_provider_sso_uri ⇒ String
Required. The URI where the SAML IdP exposes the SSO service.
Corresponds to the JSON property identityProviderSsoUri
3455 3456 3457 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3455 def identity_provider_sso_uri @identity_provider_sso_uri end |
#user_attribute ⇒ String
Optional. The SAML attribute to read username from. If unspecified, the
username will be read from the NameID element of the assertion in SAML
response. This value is expected to be a string and will be passed along as-is
(with the option of being prefixed by the user_prefix).
Corresponds to the JSON property userAttribute
3463 3464 3465 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3463 def user_attribute @user_attribute end |
#user_prefix ⇒ String
Optional. Prefix to prepend to user name.
Corresponds to the JSON property userPrefix
3468 3469 3470 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3468 def user_prefix @user_prefix end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3475 3476 3477 3478 3479 3480 3481 3482 3483 3484 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3475 def update!(**args) @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping) @group_prefix = args[:group_prefix] if args.key?(:group_prefix) @groups_attribute = args[:groups_attribute] if args.key?(:groups_attribute) @identity_provider_certificates = args[:identity_provider_certificates] if args.key?(:identity_provider_certificates) @identity_provider_id = args[:identity_provider_id] if args.key?(:identity_provider_id) @identity_provider_sso_uri = args[:identity_provider_sso_uri] if args.key?(:identity_provider_sso_uri) @user_attribute = args[:user_attribute] if args.key?(:user_attribute) @user_prefix = args[:user_prefix] if args.key?(:user_prefix) end |