Class: Google::Apis::GkehubV1beta::IdentityServiceSamlConfig

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Configuration for the SAML Auth flow.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IdentityServiceSamlConfig

Returns a new instance of IdentityServiceSamlConfig.



3456
3457
3458
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3456

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#attribute_mappingHash<String,String>

Optional. The mapping of additional user attributes like nickname, birthday and address etc.. key is the name of this additional attribute. value is a string presenting as CEL(common expression language, go/cel) used for getting the value from the resources. Take nickname as an example, in this case, key is "attribute.nickname" and value is "assertion.nickname". Corresponds to the JSON property attributeMapping

Returns:

  • (Hash<String,String>)


3414
3415
3416
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3414

def attribute_mapping
  @attribute_mapping
end

#group_prefixString

Optional. Prefix to prepend to group name. Corresponds to the JSON property groupPrefix

Returns:

  • (String)


3419
3420
3421
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3419

def group_prefix
  @group_prefix
end

#groups_attributeString

Optional. The SAML attribute to read groups from. This value is expected to be a string and will be passed along as-is (with the option of being prefixed by the group_prefix). Corresponds to the JSON property groupsAttribute

Returns:

  • (String)


3426
3427
3428
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3426

def groups_attribute
  @groups_attribute
end

#identity_provider_certificatesArray<String>

Required. The list of IdP certificates to validate the SAML response against. Corresponds to the JSON property identityProviderCertificates

Returns:

  • (Array<String>)


3431
3432
3433
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3431

def identity_provider_certificates
  @identity_provider_certificates
end

#identity_provider_idString

Required. The entity ID of the SAML IdP. Corresponds to the JSON property identityProviderId

Returns:

  • (String)


3436
3437
3438
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3436

def identity_provider_id
  @identity_provider_id
end

#identity_provider_sso_uriString

Required. The URI where the SAML IdP exposes the SSO service. Corresponds to the JSON property identityProviderSsoUri

Returns:

  • (String)


3441
3442
3443
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3441

def identity_provider_sso_uri
  @identity_provider_sso_uri
end

#user_attributeString

Optional. The SAML attribute to read username from. If unspecified, the username will be read from the NameID element of the assertion in SAML response. This value is expected to be a string and will be passed along as-is (with the option of being prefixed by the user_prefix). Corresponds to the JSON property userAttribute

Returns:

  • (String)


3449
3450
3451
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3449

def user_attribute
  @user_attribute
end

#user_prefixString

Optional. Prefix to prepend to user name. Corresponds to the JSON property userPrefix

Returns:

  • (String)


3454
3455
3456
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3454

def user_prefix
  @user_prefix
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3461
3462
3463
3464
3465
3466
3467
3468
3469
3470
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3461

def update!(**args)
  @attribute_mapping = args[:attribute_mapping] if args.key?(:attribute_mapping)
  @group_prefix = args[:group_prefix] if args.key?(:group_prefix)
  @groups_attribute = args[:groups_attribute] if args.key?(:groups_attribute)
  @identity_provider_certificates = args[:identity_provider_certificates] if args.key?(:identity_provider_certificates)
  @identity_provider_id = args[:identity_provider_id] if args.key?(:identity_provider_id)
  @identity_provider_sso_uri = args[:identity_provider_sso_uri] if args.key?(:identity_provider_sso_uri)
  @user_attribute = args[:user_attribute] if args.key?(:user_attribute)
  @user_prefix = args[:user_prefix] if args.key?(:user_prefix)
end