Class: Google::Apis::GkehubV1beta::ListBoundMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListBoundMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of Memberships bound to a Scope.
Instance Attribute Summary collapse
-
#memberships ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of Memberships bound to the given Scope.
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListBoundMembershipsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListBoundMembershipsResponse
constructor
A new instance of ListBoundMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListBoundMembershipsResponse
Returns a new instance of ListBoundMembershipsResponse.
3638 3639 3640 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3638 def initialize(**args) update!(**args) end |
Instance Attribute Details
#memberships ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of Memberships bound to the given Scope.
Corresponds to the JSON property memberships
3624 3625 3626 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3624 def memberships @memberships end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListBoundMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3631 3632 3633 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3631 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3636 3637 3638 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3636 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3643 3644 3645 3646 3647 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3643 def update!(**args) @memberships = args[:memberships] if args.key?(:memberships) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |