Class: Google::Apis::GkehubV1beta::ListFeaturesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListFeaturesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Response message for the GkeHub.ListFeatures method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListFeaturesmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1beta::Feature>
The list of matching Features Corresponds to the JSON property
resources.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListFeaturesResponse
constructor
A new instance of ListFeaturesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListFeaturesResponse
Returns a new instance of ListFeaturesResponse.
3790 3791 3792 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3790 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListFeatures method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
3783 3784 3785 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3783 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1beta::Feature>
The list of matching Features
Corresponds to the JSON property resources
3788 3789 3790 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3788 def resources @resources end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3795 3796 3797 3798 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3795 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) end |