Class: Google::Apis::GkehubV1beta::ListFeaturesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Response message for the GkeHub.ListFeatures method.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFeaturesResponse

Returns a new instance of ListFeaturesResponse.



3665
3666
3667
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3665

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListFeatures method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3658
3659
3660
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3658

def next_page_token
  @next_page_token
end

#resourcesArray<Google::Apis::GkehubV1beta::Feature>

The list of matching Features Corresponds to the JSON property resources



3663
3664
3665
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3663

def resources
  @resources
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3670
3671
3672
3673
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3670

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @resources = args[:resources] if args.key?(:resources)
end