Class: Google::Apis::GkehubV1beta::ListMembershipBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListMembershipBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of MembershipBindings.
Instance Attribute Summary collapse
-
#membership_bindings ⇒ Array<Google::Apis::GkehubV1beta::MembershipBinding>
The list of membership_bindings Corresponds to the JSON property
membershipBindings. -
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipBindingsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipBindingsResponse
constructor
A new instance of ListMembershipBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipBindingsResponse
Returns a new instance of ListMembershipBindingsResponse.
3881 3882 3883 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3881 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership_bindings ⇒ Array<Google::Apis::GkehubV1beta::MembershipBinding>
The list of membership_bindings
Corresponds to the JSON property membershipBindings
3867 3868 3869 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3867 def membership_bindings @membership_bindings end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListMembershipBindings
method. The value of an empty string means that there are no more resources
to return.
Corresponds to the JSON property nextPageToken
3874 3875 3876 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3874 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3879 3880 3881 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3879 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3886 3887 3888 3889 3890 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3886 def update!(**args) @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |