Class: Google::Apis::GkehubV1beta::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipBindingsResponse

Returns a new instance of ListMembershipBindingsResponse.



3871
3872
3873
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3871

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_bindingsArray<Google::Apis::GkehubV1beta::MembershipBinding>

The list of membership_bindings Corresponds to the JSON property membershipBindings



3857
3858
3859
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3857

def membership_bindings
  @membership_bindings
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3864
3865
3866
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3864

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3869
3870
3871
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3869

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3876
3877
3878
3879
3880
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3876

def update!(**args)
  @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end