Class: Google::Apis::GkehubV1beta::ListMembershipBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListMembershipBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of MembershipBindings.
Instance Attribute Summary collapse
-
#membership_bindings ⇒ Array<Google::Apis::GkehubV1beta::MembershipBinding>
The list of membership_bindings Corresponds to the JSON property
membershipBindings. -
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipBindingsmethod. -
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipBindingsResponse
constructor
A new instance of ListMembershipBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipBindingsResponse
Returns a new instance of ListMembershipBindingsResponse.
3857 3858 3859 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3857 def initialize(**args) update!(**args) end |
Instance Attribute Details
#membership_bindings ⇒ Array<Google::Apis::GkehubV1beta::MembershipBinding>
The list of membership_bindings
Corresponds to the JSON property membershipBindings
3843 3844 3845 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3843 def membership_bindings @membership_bindings end |
#next_page_token ⇒ String
A token to request the next page of resources from the ListMembershipBindings
method. The value of an empty string means that there are no more resources
to return.
Corresponds to the JSON property nextPageToken
3850 3851 3852 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3850 def next_page_token @next_page_token end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3855 3856 3857 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3855 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3862 3863 3864 3865 3866 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3862 def update!(**args) @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @unreachable = args[:unreachable] if args.key?(:unreachable) end |