Class: Google::Apis::GkehubV1beta::ListMembershipBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of MembershipBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListMembershipBindingsResponse

Returns a new instance of ListMembershipBindingsResponse.



3749
3750
3751
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3749

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#membership_bindingsArray<Google::Apis::GkehubV1beta::MembershipBinding>

The list of membership_bindings Corresponds to the JSON property membershipBindings



3735
3736
3737
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3735

def membership_bindings
  @membership_bindings
end

#next_page_tokenString

A token to request the next page of resources from the ListMembershipBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3742
3743
3744
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3742

def next_page_token
  @next_page_token
end

#unreachableArray<String>

List of locations that could not be reached while fetching this list. Corresponds to the JSON property unreachable

Returns:

  • (Array<String>)


3747
3748
3749
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3747

def unreachable
  @unreachable
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3754
3755
3756
3757
3758
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3754

def update!(**args)
  @membership_bindings = args[:membership_bindings] if args.key?(:membership_bindings)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @unreachable = args[:unreachable] if args.key?(:unreachable)
end