Class: Google::Apis::GkehubV1beta::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
3937 3938 3939 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3925 3926 3927 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3925 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
3930 3931 3932 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3930 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3935 3936 3937 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3935 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3942 3943 3944 3945 3946 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3942 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |