Class: Google::Apis::GkehubV1beta::ListMembershipsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListMembershipsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Response message for the GkeHub.ListMemberships method.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListMembershipsmethod. -
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
-
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListMembershipsResponse
constructor
A new instance of ListMembershipsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListMembershipsResponse
Returns a new instance of ListMembershipsResponse.
3815 3816 3817 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3815 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListMemberships
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3803 3804 3805 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3803 def next_page_token @next_page_token end |
#resources ⇒ Array<Google::Apis::GkehubV1beta::Membership>
The list of matching Memberships.
Corresponds to the JSON property resources
3808 3809 3810 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3808 def resources @resources end |
#unreachable ⇒ Array<String>
List of locations that could not be reached while fetching this list.
Corresponds to the JSON property unreachable
3813 3814 3815 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3813 def unreachable @unreachable end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3820 3821 3822 3823 3824 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3820 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @resources = args[:resources] if args.key?(:resources) @unreachable = args[:unreachable] if args.key?(:unreachable) end |