Class: Google::Apis::GkehubV1beta::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListPermittedScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of permitted Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPermittedScopesResponse
constructor
A new instance of ListPermittedScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPermittedScopesResponse
Returns a new instance of ListPermittedScopesResponse.
4009 4010 4011 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4009 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListPermittedScopes
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
4002 4003 4004 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4002 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of permitted Scopes
Corresponds to the JSON property scopes
4007 4008 4009 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4007 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4014 4015 4016 4017 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4014 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |