Class: Google::Apis::GkehubV1beta::ListPermittedScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of permitted Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListPermittedScopesResponse

Returns a new instance of ListPermittedScopesResponse.



3985
3986
3987
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3985

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListPermittedScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


3978
3979
3980
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3978

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1beta::Scope>

The list of permitted Scopes Corresponds to the JSON property scopes



3983
3984
3985
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3983

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3990
3991
3992
3993
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3990

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end