Class: Google::Apis::GkehubV1beta::ListPermittedScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListPermittedScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of permitted Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListPermittedScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of permitted Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListPermittedScopesResponse
constructor
A new instance of ListPermittedScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListPermittedScopesResponse
Returns a new instance of ListPermittedScopesResponse.
3876 3877 3878 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3876 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListPermittedScopes
method. The value of an empty string means that there are no more resources to
return.
Corresponds to the JSON property nextPageToken
3869 3870 3871 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3869 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of permitted Scopes
Corresponds to the JSON property scopes
3874 3875 3876 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3874 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3881 3882 3883 3884 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3881 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |