Class: Google::Apis::GkehubV1beta::ListScopeNamespacesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of fleet namespaces.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeNamespacesResponse

Returns a new instance of ListScopeNamespacesResponse.



4063
4064
4065
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4063

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListNamespaces method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4056
4057
4058
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4056

def next_page_token
  @next_page_token
end

#scope_namespacesArray<Google::Apis::GkehubV1beta::Namespace>

The list of fleet namespaces Corresponds to the JSON property scopeNamespaces



4061
4062
4063
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4061

def scope_namespaces
  @scope_namespaces
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4068
4069
4070
4071
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4068

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scope_namespaces = args[:scope_namespaces] if args.key?(:scope_namespaces)
end