Class: Google::Apis::GkehubV1beta::ListScopeRbacRoleBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListScopeRbacRoleBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of Scope RBACRoleBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopeRBACRoleBindingsmethod. -
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1beta::RbacRoleBinding>
The list of Scope RBACRoleBindings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse
constructor
A new instance of ListScopeRbacRoleBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse
Returns a new instance of ListScopeRbacRoleBindingsResponse.
4107 4108 4109 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4107 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopeRBACRoleBindings method. The value of an empty string means that
there are no more resources to return.
Corresponds to the JSON property nextPageToken
4100 4101 4102 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4100 def next_page_token @next_page_token end |
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1beta::RbacRoleBinding>
The list of Scope RBACRoleBindings.
Corresponds to the JSON property rbacrolebindings
4105 4106 4107 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4105 def rbacrolebindings @rbacrolebindings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4112 4113 4114 4115 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4112 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings) end |