Class: Google::Apis::GkehubV1beta::ListScopeRbacRoleBindingsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of Scope RBACRoleBindings.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse

Returns a new instance of ListScopeRbacRoleBindingsResponse.



4104
4105
4106
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4104

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopeRBACRoleBindings method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4097
4098
4099
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4097

def next_page_token
  @next_page_token
end

#rbacrolebindingsArray<Google::Apis::GkehubV1beta::RbacRoleBinding>

The list of Scope RBACRoleBindings. Corresponds to the JSON property rbacrolebindings



4102
4103
4104
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4102

def rbacrolebindings
  @rbacrolebindings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4109
4110
4111
4112
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4109

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings)
end