Class: Google::Apis::GkehubV1beta::ListScopeRbacRoleBindingsResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListScopeRbacRoleBindingsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of Scope RBACRoleBindings.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopeRBACRoleBindingsmethod. -
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1beta::RbacRoleBinding>
The list of Scope RBACRoleBindings.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse
constructor
A new instance of ListScopeRbacRoleBindingsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopeRbacRoleBindingsResponse
Returns a new instance of ListScopeRbacRoleBindingsResponse.
3929 3930 3931 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3929 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopeRBACRoleBindings method. The value of an empty string means that
there are no more resources to return.
Corresponds to the JSON property nextPageToken
3922 3923 3924 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3922 def next_page_token @next_page_token end |
#rbacrolebindings ⇒ Array<Google::Apis::GkehubV1beta::RbacRoleBinding>
The list of Scope RBACRoleBindings.
Corresponds to the JSON property rbacrolebindings
3927 3928 3929 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3927 def rbacrolebindings @rbacrolebindings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3934 3935 3936 3937 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 3934 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @rbacrolebindings = args[:rbacrolebindings] if args.key?(:rbacrolebindings) end |