Class: Google::Apis::GkehubV1beta::ListScopesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

List of Scopes.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListScopesResponse

Returns a new instance of ListScopesResponse.



4133
4134
4135
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4133

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#next_page_tokenString

A token to request the next page of resources from the ListScopes method. The value of an empty string means that there are no more resources to return. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


4126
4127
4128
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4126

def next_page_token
  @next_page_token
end

#scopesArray<Google::Apis::GkehubV1beta::Scope>

The list of Scopes Corresponds to the JSON property scopes



4131
4132
4133
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4131

def scopes
  @scopes
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4138
4139
4140
4141
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4138

def update!(**args)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @scopes = args[:scopes] if args.key?(:scopes)
end