Class: Google::Apis::GkehubV1beta::ListScopesResponse
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ListScopesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
List of Scopes.
Instance Attribute Summary collapse
-
#next_page_token ⇒ String
A token to request the next page of resources from the
ListScopesmethod. -
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of Scopes Corresponds to the JSON property
scopes.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListScopesResponse
constructor
A new instance of ListScopesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListScopesResponse
Returns a new instance of ListScopesResponse.
4130 4131 4132 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4130 def initialize(**args) update!(**args) end |
Instance Attribute Details
#next_page_token ⇒ String
A token to request the next page of resources from the ListScopes method.
The value of an empty string means that there are no more resources to return.
Corresponds to the JSON property nextPageToken
4123 4124 4125 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4123 def next_page_token @next_page_token end |
#scopes ⇒ Array<Google::Apis::GkehubV1beta::Scope>
The list of Scopes
Corresponds to the JSON property scopes
4128 4129 4130 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4128 def scopes @scopes end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4135 4136 4137 4138 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4135 def update!(**args) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @scopes = args[:scopes] if args.key?(:scopes) end |