Class: Google::Apis::GkehubV1beta::Membership
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Membership
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Membership contains information about a member cluster.
Instance Attribute Summary collapse
-
#authority ⇒ Google::Apis::GkehubV1beta::Authority
Authority encodes how Google will recognize identities from this Membership.
-
#cluster_tier ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#description ⇒ String
Output only.
-
#endpoint ⇒ Google::Apis::GkehubV1beta::MembershipEndpoint
MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.
-
#external_id ⇒ String
Optional.
-
#labels ⇒ Hash<String,String>
Optional.
-
#last_connection_time ⇒ String
Output only.
-
#membership_type ⇒ String
Output only.
-
#monitoring_config ⇒ Google::Apis::GkehubV1beta::MonitoringConfig
MonitoringConfig informs Fleet-based applications/services/UIs how the metrics for the underlying cluster is reported to cloud monitoring services.
-
#name ⇒ String
Output only.
-
#state ⇒ Google::Apis::GkehubV1beta::MembershipState
MembershipState describes the state of a Membership resource.
-
#unique_id ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Membership
constructor
A new instance of Membership.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Membership
Returns a new instance of Membership.
4115 4116 4117 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4115 def initialize(**args) update!(**args) end |
Instance Attribute Details
#authority ⇒ Google::Apis::GkehubV1beta::Authority
Authority encodes how Google will recognize identities from this Membership.
See the workload identity documentation for more details: https://cloud.google.
com/kubernetes-engine/docs/how-to/workload-identity
Corresponds to the JSON property authority
4022 4023 4024 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4022 def @authority end |
#cluster_tier ⇒ String
Output only. The tier of the cluster.
Corresponds to the JSON property clusterTier
4027 4028 4029 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4027 def cluster_tier @cluster_tier end |
#create_time ⇒ String
Output only. When the Membership was created.
Corresponds to the JSON property createTime
4032 4033 4034 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4032 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the Membership was deleted.
Corresponds to the JSON property deleteTime
4037 4038 4039 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4037 def delete_time @delete_time end |
#description ⇒ String
Output only. Description of this membership, limited to 63 characters. Must
match the regex: a-zA-Z0-9* This field is present for legacy purposes.
Corresponds to the JSON property description
4043 4044 4045 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4043 def description @description end |
#endpoint ⇒ Google::Apis::GkehubV1beta::MembershipEndpoint
MembershipEndpoint contains information needed to contact a Kubernetes API,
endpoint and any additional Kubernetes metadata.
Corresponds to the JSON property endpoint
4049 4050 4051 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4049 def endpoint @endpoint end |
#external_id ⇒ String
Optional. An externally-generated and managed ID for this Membership. This ID
may be modified after creation, but this is not recommended. The ID must match
the regex: a-zA-Z0-9* If this Membership represents a Kubernetes cluster,
this value should be set to the UID of the kube-system namespace object.
Corresponds to the JSON property externalId
4057 4058 4059 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4057 def external_id @external_id end |
#labels ⇒ Hash<String,String>
Optional. Labels for this membership. These labels are not leveraged by multi-
cluster features, instead, we prefer cluster labels, which can be set on GKE
cluster or other cluster types.
Corresponds to the JSON property labels
4064 4065 4066 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4064 def labels @labels end |
#last_connection_time ⇒ String
Output only. For clusters using Connect, the timestamp of the most recent
connection established with Google Cloud. This time is updated every several
minutes, not continuously. For clusters that do not use GKE Connect, or that
have never connected successfully, this field will be unset.
Corresponds to the JSON property lastConnectionTime
4072 4073 4074 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4072 def last_connection_time @last_connection_time end |
#membership_type ⇒ String
Output only. The type of the membership.
Corresponds to the JSON property membershipType
4077 4078 4079 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4077 def membership_type @membership_type end |
#monitoring_config ⇒ Google::Apis::GkehubV1beta::MonitoringConfig
MonitoringConfig informs Fleet-based applications/services/UIs how the metrics
for the underlying cluster is reported to cloud monitoring services. It can be
set from empty to non-empty, but can't be mutated directly to prevent
accidentally breaking the constinousty of metrics.
Corresponds to the JSON property monitoringConfig
4085 4086 4087 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4085 def monitoring_config @monitoring_config end |
#name ⇒ String
Output only. The full, unique name of this Membership resource in the format
projects/*/locations/*/memberships/membership_id`, set during creation.
membership_idmust be a valid RFC 1123 compliant DNS label: 1. At most 63
characters in length 2. It must consist of lower case alphanumeric characters
or-3. It must start and end with an alphanumeric character Which can be
expressed as the regex:a-z0-9?, with a maximum length
of 63 characters.
Corresponds to the JSON propertyname`
4096 4097 4098 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4096 def name @name end |
#state ⇒ Google::Apis::GkehubV1beta::MembershipState
MembershipState describes the state of a Membership resource.
Corresponds to the JSON property state
4101 4102 4103 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4101 def state @state end |
#unique_id ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Membership resources. If a Membership resource is deleted and another
resource with the same name is created, it gets a different unique_id.
Corresponds to the JSON property uniqueId
4108 4109 4110 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4108 def unique_id @unique_id end |
#update_time ⇒ String
Output only. When the Membership was last updated.
Corresponds to the JSON property updateTime
4113 4114 4115 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4113 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4120 4121 4122 4123 4124 4125 4126 4127 4128 4129 4130 4131 4132 4133 4134 4135 4136 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4120 def update!(**args) @authority = args[:authority] if args.key?(:authority) @cluster_tier = args[:cluster_tier] if args.key?(:cluster_tier) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @description = args[:description] if args.key?(:description) @endpoint = args[:endpoint] if args.key?(:endpoint) @external_id = args[:external_id] if args.key?(:external_id) @labels = args[:labels] if args.key?(:labels) @last_connection_time = args[:last_connection_time] if args.key?(:last_connection_time) @membership_type = args[:membership_type] if args.key?(:membership_type) @monitoring_config = args[:monitoring_config] if args.key?(:monitoring_config) @name = args[:name] if args.key?(:name) @state = args[:state] if args.key?(:state) @unique_id = args[:unique_id] if args.key?(:unique_id) @update_time = args[:update_time] if args.key?(:update_time) end |