Class: Google::Apis::GkehubV1beta::MembershipEndpoint

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

MembershipEndpoint contains information needed to contact a Kubernetes API, endpoint and any additional Kubernetes metadata.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MembershipEndpoint

Returns a new instance of MembershipEndpoint.



4434
4435
4436
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4434

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#appliance_clusterGoogle::Apis::GkehubV1beta::ApplianceCluster

ApplianceCluster contains information specific to GDC Edge Appliance Clusters. Corresponds to the JSON property applianceCluster



4392
4393
4394
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4392

def appliance_cluster
  @appliance_cluster
end

#edge_clusterGoogle::Apis::GkehubV1beta::EdgeCluster

EdgeCluster contains information specific to Google Edge Clusters. Corresponds to the JSON property edgeCluster



4397
4398
4399
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4397

def edge_cluster
  @edge_cluster
end

#gke_clusterGoogle::Apis::GkehubV1beta::GkeCluster

GkeCluster contains information specific to GKE clusters. Corresponds to the JSON property gkeCluster



4402
4403
4404
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4402

def gke_cluster
  @gke_cluster
end

#google_managedBoolean Also known as: google_managed?

Output only. Whether the lifecycle of this membership is managed by a google cluster platform service. Corresponds to the JSON property googleManaged

Returns:

  • (Boolean)


4408
4409
4410
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4408

def google_managed
  @google_managed
end

#kubernetes_metadataGoogle::Apis::GkehubV1beta::KubernetesMetadata

KubernetesMetadata provides informational metadata for Memberships representing Kubernetes clusters. Corresponds to the JSON property kubernetesMetadata



4415
4416
4417
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4415

def 
  @kubernetes_metadata
end

#kubernetes_resourceGoogle::Apis::GkehubV1beta::KubernetesResource

KubernetesResource contains the YAML manifests and configuration for Membership Kubernetes resources in the cluster. After CreateMembership or UpdateMembership, these resources should be re-applied in the cluster. Corresponds to the JSON property kubernetesResource



4422
4423
4424
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4422

def kubernetes_resource
  @kubernetes_resource
end

#multi_cloud_clusterGoogle::Apis::GkehubV1beta::MultiCloudCluster

MultiCloudCluster contains information specific to GKE Multi-Cloud clusters. Corresponds to the JSON property multiCloudCluster



4427
4428
4429
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4427

def multi_cloud_cluster
  @multi_cloud_cluster
end

#on_prem_clusterGoogle::Apis::GkehubV1beta::OnPremCluster

OnPremCluster contains information specific to GKE On-Prem clusters. Corresponds to the JSON property onPremCluster



4432
4433
4434
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4432

def on_prem_cluster
  @on_prem_cluster
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4439
4440
4441
4442
4443
4444
4445
4446
4447
4448
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4439

def update!(**args)
  @appliance_cluster = args[:appliance_cluster] if args.key?(:appliance_cluster)
  @edge_cluster = args[:edge_cluster] if args.key?(:edge_cluster)
  @gke_cluster = args[:gke_cluster] if args.key?(:gke_cluster)
  @google_managed = args[:google_managed] if args.key?(:google_managed)
  @kubernetes_metadata = args[:kubernetes_metadata] if args.key?(:kubernetes_metadata)
  @kubernetes_resource = args[:kubernetes_resource] if args.key?(:kubernetes_resource)
  @multi_cloud_cluster = args[:multi_cloud_cluster] if args.key?(:multi_cloud_cluster)
  @on_prem_cluster = args[:on_prem_cluster] if args.key?(:on_prem_cluster)
end