Class: Google::Apis::GkehubV1beta::MembershipFeatureState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::MembershipFeatureState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
MembershipFeatureState contains Feature status information for a single Membership.
Instance Attribute Summary collapse
-
#appdevexperience ⇒ Google::Apis::GkehubV1beta::AppDevExperienceFeatureState
State for App Dev Exp Feature.
-
#clusterupgrade ⇒ Google::Apis::GkehubV1beta::ClusterUpgradeMembershipState
Per-membership state for this feature.
-
#configmanagement ⇒ Google::Apis::GkehubV1beta::ConfigManagementMembershipState
Anthos Config Management: State for a single cluster.
-
#fleetobservability ⇒ Google::Apis::GkehubV1beta::FleetObservabilityMembershipState
FleetObservability: Membership-specific Feature state for fleetobservability.
-
#identityservice ⇒ Google::Apis::GkehubV1beta::IdentityServiceMembershipState
Anthos Identity Service: State for a single Membership.
-
#metering ⇒ Google::Apis::GkehubV1beta::MeteringMembershipState
Metering: Per-Membership Feature State.
-
#policycontroller ⇒ Google::Apis::GkehubV1beta::PolicyControllerMembershipState
Policy Controller: State for a single cluster.
-
#servicemesh ⇒ Google::Apis::GkehubV1beta::ServiceMeshMembershipState
Service Mesh: State for a single Membership, as analyzed by the Service Mesh Hub Controller.
-
#state ⇒ Google::Apis::GkehubV1beta::FeatureState
FeatureState describes the high-level state of a Feature.
-
#workloadidentity ⇒ Google::Apis::GkehubV1beta::WorkloadIdentityMembershipState
WorkloadIdentity: The membership-specific state for WorkloadIdentity feature.
Instance Method Summary collapse
-
#initialize(**args) ⇒ MembershipFeatureState
constructor
A new instance of MembershipFeatureState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ MembershipFeatureState
Returns a new instance of MembershipFeatureState.
4570 4571 4572 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4570 def initialize(**args) update!(**args) end |
Instance Attribute Details
#appdevexperience ⇒ Google::Apis::GkehubV1beta::AppDevExperienceFeatureState
State for App Dev Exp Feature.
Corresponds to the JSON property appdevexperience
4518 4519 4520 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4518 def appdevexperience @appdevexperience end |
#clusterupgrade ⇒ Google::Apis::GkehubV1beta::ClusterUpgradeMembershipState
Per-membership state for this feature.
Corresponds to the JSON property clusterupgrade
4523 4524 4525 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4523 def clusterupgrade @clusterupgrade end |
#configmanagement ⇒ Google::Apis::GkehubV1beta::ConfigManagementMembershipState
Anthos Config Management: State for a single cluster.
Corresponds to the JSON property configmanagement
4528 4529 4530 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4528 def configmanagement @configmanagement end |
#fleetobservability ⇒ Google::Apis::GkehubV1beta::FleetObservabilityMembershipState
FleetObservability: Membership-specific Feature state for
fleetobservability.
Corresponds to the JSON property fleetobservability
4534 4535 4536 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4534 def fleetobservability @fleetobservability end |
#identityservice ⇒ Google::Apis::GkehubV1beta::IdentityServiceMembershipState
Anthos Identity Service: State for a single Membership.
Corresponds to the JSON property identityservice
4539 4540 4541 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4539 def identityservice @identityservice end |
#metering ⇒ Google::Apis::GkehubV1beta::MeteringMembershipState
Metering: Per-Membership Feature State.
Corresponds to the JSON property metering
4544 4545 4546 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4544 def metering @metering end |
#policycontroller ⇒ Google::Apis::GkehubV1beta::PolicyControllerMembershipState
Policy Controller: State for a single cluster.
Corresponds to the JSON property policycontroller
4549 4550 4551 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4549 def policycontroller @policycontroller end |
#servicemesh ⇒ Google::Apis::GkehubV1beta::ServiceMeshMembershipState
Service Mesh: State for a single Membership, as analyzed by the Service
Mesh Hub Controller.
Corresponds to the JSON property servicemesh
4555 4556 4557 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4555 def servicemesh @servicemesh end |
#state ⇒ Google::Apis::GkehubV1beta::FeatureState
FeatureState describes the high-level state of a Feature. It may be used to
describe a Feature's state at the environ-level, or per-membershop, depending
on the context.
Corresponds to the JSON property state
4562 4563 4564 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4562 def state @state end |
#workloadidentity ⇒ Google::Apis::GkehubV1beta::WorkloadIdentityMembershipState
WorkloadIdentity: The membership-specific state for WorkloadIdentity
feature.
Corresponds to the JSON property workloadidentity
4568 4569 4570 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4568 def workloadidentity @workloadidentity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4575 4576 4577 4578 4579 4580 4581 4582 4583 4584 4585 4586 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 4575 def update!(**args) @appdevexperience = args[:appdevexperience] if args.key?(:appdevexperience) @clusterupgrade = args[:clusterupgrade] if args.key?(:clusterupgrade) @configmanagement = args[:configmanagement] if args.key?(:configmanagement) @fleetobservability = args[:fleetobservability] if args.key?(:fleetobservability) @identityservice = args[:identityservice] if args.key?(:identityservice) @metering = args[:metering] if args.key?(:metering) @policycontroller = args[:policycontroller] if args.key?(:policycontroller) @servicemesh = args[:servicemesh] if args.key?(:servicemesh) @state = args[:state] if args.key?(:state) @workloadidentity = args[:workloadidentity] if args.key?(:workloadidentity) end |