Class: Google::Apis::GkehubV1beta::OperationalState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::OperationalState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Operational state of the Rollout Sequence.
Instance Attribute Summary collapse
-
#reasons ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#state_change_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationalState
constructor
A new instance of OperationalState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationalState
Returns a new instance of OperationalState.
5063 5064 5065 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5063 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reasons ⇒ Array<String>
Output only. Reasons for the Rollout Sequence state.
Corresponds to the JSON property reasons
5050 5051 5052 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5050 def reasons @reasons end |
#state ⇒ String
Output only. State of the Rollout Sequence.
Corresponds to the JSON property state
5055 5056 5057 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5055 def state @state end |
#state_change_time ⇒ String
Output only. The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Corresponds to the JSON property stateChangeTime
5061 5062 5063 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5061 def state_change_time @state_change_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5068 5069 5070 5071 5072 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5068 def update!(**args) @reasons = args[:reasons] if args.key?(:reasons) @state = args[:state] if args.key?(:state) @state_change_time = args[:state_change_time] if args.key?(:state_change_time) end |