Class: Google::Apis::GkehubV1beta::OperationalState
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::OperationalState
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Operational state of the Rollout Sequence.
Instance Attribute Summary collapse
-
#reasons ⇒ Array<String>
Output only.
-
#state ⇒ String
Output only.
-
#state_change_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ OperationalState
constructor
A new instance of OperationalState.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ OperationalState
Returns a new instance of OperationalState.
5049 5050 5051 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5049 def initialize(**args) update!(**args) end |
Instance Attribute Details
#reasons ⇒ Array<String>
Output only. Reasons for the Rollout Sequence state.
Corresponds to the JSON property reasons
5036 5037 5038 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5036 def reasons @reasons end |
#state ⇒ String
Output only. State of the Rollout Sequence.
Corresponds to the JSON property state
5041 5042 5043 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5041 def state @state end |
#state_change_time ⇒ String
Output only. The timestamp at which the operational state was last changed.
Used to track how long it has been in the current state.
Corresponds to the JSON property stateChangeTime
5047 5048 5049 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5047 def state_change_time @state_change_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5054 5055 5056 5057 5058 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5054 def update!(**args) @reasons = args[:reasons] if args.key?(:reasons) @state = args[:state] if args.key?(:state) @state_change_time = args[:state_change_time] if args.key?(:state_change_time) end |