Class: Google::Apis::GkehubV1beta::RbacRoleBinding

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

RBACRoleBinding represents a rbacrolebinding across the Fleet

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RbacRoleBinding

Returns a new instance of RbacRoleBinding.



5706
5707
5708
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5706

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#create_timeString

Output only. When the rbacrolebinding was created. Corresponds to the JSON property createTime

Returns:

  • (String)


5652
5653
5654
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5652

def create_time
  @create_time
end

#delete_timeString

Output only. When the rbacrolebinding was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


5657
5658
5659
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5657

def delete_time
  @delete_time
end

#groupString

group is the group, as seen by the kubernetes cluster. Corresponds to the JSON property group

Returns:

  • (String)


5662
5663
5664
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5662

def group
  @group
end

#labelsHash<String,String>

Optional. Labels for this RBACRolebinding. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


5667
5668
5669
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5667

def labels
  @labels
end

#nameString

The resource name for the rbacrolebinding projects/project/locations/ location/scopes/scope/rbacrolebindings/rbacrolebindingor `projects/` project`/locations/`location`/memberships/`membership`/rbacrolebindings/` rbacrolebinding Corresponds to the JSON property name

Returns:

  • (String)


5675
5676
5677
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5675

def name
  @name
end

#roleGoogle::Apis::GkehubV1beta::Role

Role is the type for Kubernetes roles Corresponds to the JSON property role



5680
5681
5682
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5680

def role
  @role
end

#stateGoogle::Apis::GkehubV1beta::RbacRoleBindingLifecycleState

RBACRoleBindingLifecycleState describes the state of a RbacRoleBinding resource. Corresponds to the JSON property state



5686
5687
5688
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5686

def state
  @state
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all rbacrolebinding resources. If a rbacrolebinding resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


5693
5694
5695
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5693

def uid
  @uid
end

#update_timeString

Output only. When the rbacrolebinding was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


5698
5699
5700
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5698

def update_time
  @update_time
end

#userString

user is the name of the user as seen by the kubernetes cluster, example "alice" or "alice@domain.tld" Corresponds to the JSON property user

Returns:

  • (String)


5704
5705
5706
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5704

def user
  @user
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5711
5712
5713
5714
5715
5716
5717
5718
5719
5720
5721
5722
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5711

def update!(**args)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @group = args[:group] if args.key?(:group)
  @labels = args[:labels] if args.key?(:labels)
  @name = args[:name] if args.key?(:name)
  @role = args[:role] if args.key?(:role)
  @state = args[:state] if args.key?(:state)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
  @user = args[:user] if args.key?(:user)
end