Class: Google::Apis::GkehubV1beta::Rollout
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Rollout
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Rollout contains the Rollout metadata and configuration. Next ID: 31
Instance Attribute Summary collapse
-
#complete_time ⇒ String
Output only.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#etag ⇒ String
Output only.
-
#intent ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1beta::RolloutMembershipState>
Output only.
-
#name ⇒ String
Identifier.
-
#rollout_sequence ⇒ String
Optional.
-
#stages ⇒ Array<Google::Apis::GkehubV1beta::RolloutStage>
Output only.
-
#state ⇒ String
Output only.
-
#state_reason ⇒ String
Output only.
-
#state_reason_type ⇒ String
Output only.
-
#trigger ⇒ String
Output only.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
-
#version_upgrade ⇒ Google::Apis::GkehubV1beta::VersionUpgrade
Config for version upgrade of clusters.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Rollout
constructor
A new instance of Rollout.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Rollout
Returns a new instance of Rollout.
6018 6019 6020 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6018 def initialize(**args) update!(**args) end |
Instance Attribute Details
#complete_time ⇒ String
Output only. The timestamp at which the Rollout was completed.
Corresponds to the JSON property completeTime
5923 5924 5925 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5923 def complete_time @complete_time end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout was created.
Corresponds to the JSON property createTime
5928 5929 5930 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5928 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout was deleted.
Corresponds to the JSON property deleteTime
5933 5934 5935 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5933 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout.
Corresponds to the JSON property displayName
5938 5939 5940 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5938 def display_name @display_name end |
#etag ⇒ String
Output only. etag of the Rollout Ex. abc1234
Corresponds to the JSON property etag
5943 5944 5945 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5943 def etag @etag end |
#intent ⇒ String
Output only. The intent of the rollout.
Corresponds to the JSON property intent
5948 5949 5950 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5948 def intent @intent end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout.
Corresponds to the JSON property labels
5953 5954 5955 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5953 def labels @labels end |
#membership_states ⇒ Hash<String,Google::Apis::GkehubV1beta::RolloutMembershipState>
Output only. States of upgrading control plane or node pool targets of a
single cluster (GKE Hub membership) that's part of this Rollout. The key is
the membership name of the cluster. The value is the state of the cluster.
Corresponds to the JSON property membershipStates
5960 5961 5962 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5960 def membership_states @membership_states end |
#name ⇒ String
Identifier. The full, unique resource name of this Rollout in the format of
projects/project/locations/global/rollouts/rollout`.
Corresponds to the JSON propertyname`
5966 5967 5968 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5966 def name @name end |
#rollout_sequence ⇒ String
Optional. Immutable. The full, unique resource name of the rollout sequence
that initiatied this Rollout. In the format of projects/project/locations/
global/rolloutSequences/rollout_sequence`.
Corresponds to the JSON propertyrolloutSequence`
5973 5974 5975 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5973 def rollout_sequence @rollout_sequence end |
#stages ⇒ Array<Google::Apis::GkehubV1beta::RolloutStage>
Output only. The stages of the Rollout.
Corresponds to the JSON property stages
5978 5979 5980 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5978 def stages @stages end |
#state ⇒ String
Output only. State specifies various states of the Rollout.
Corresponds to the JSON property state
5983 5984 5985 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5983 def state @state end |
#state_reason ⇒ String
Output only. A human-readable description explaining the reason for the
current state.
Corresponds to the JSON property stateReason
5989 5990 5991 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5989 def state_reason @state_reason end |
#state_reason_type ⇒ String
Output only. StateReasonType specifies the reason type of the Rollout state.
Corresponds to the JSON property stateReasonType
5994 5995 5996 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5994 def state_reason_type @state_reason_type end |
#trigger ⇒ String
Output only. The trigger of the rollout.
Corresponds to the JSON property trigger
5999 6000 6001 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 5999 def trigger @trigger end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout resources. If a Rollout resource is deleted and another resource
with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6006 6007 6008 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6006 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout was last updated.
Corresponds to the JSON property updateTime
6011 6012 6013 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6011 def update_time @update_time end |
#version_upgrade ⇒ Google::Apis::GkehubV1beta::VersionUpgrade
Config for version upgrade of clusters.
Corresponds to the JSON property versionUpgrade
6016 6017 6018 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6016 def version_upgrade @version_upgrade end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6023 6024 6025 6026 6027 6028 6029 6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 6042 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6023 def update!(**args) @complete_time = args[:complete_time] if args.key?(:complete_time) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @etag = args[:etag] if args.key?(:etag) @intent = args[:intent] if args.key?(:intent) @labels = args[:labels] if args.key?(:labels) @membership_states = args[:membership_states] if args.key?(:membership_states) @name = args[:name] if args.key?(:name) @rollout_sequence = args[:rollout_sequence] if args.key?(:rollout_sequence) @stages = args[:stages] if args.key?(:stages) @state = args[:state] if args.key?(:state) @state_reason = args[:state_reason] if args.key?(:state_reason) @state_reason_type = args[:state_reason_type] if args.key?(:state_reason_type) @trigger = args[:trigger] if args.key?(:trigger) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) @version_upgrade = args[:version_upgrade] if args.key?(:version_upgrade) end |