Class: Google::Apis::GkehubV1beta::RolloutSequence

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

RolloutSequence defines the desired order of upgrades. Next ID: 20

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RolloutSequence

Returns a new instance of RolloutSequence.



6185
6186
6187
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6185

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#auto_upgrade_configGoogle::Apis::GkehubV1beta::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property autoUpgradeConfig



6095
6096
6097
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6095

def auto_upgrade_config
  @auto_upgrade_config
end

#computed_release_channelString

Output only. The computed release channel used for the Rollout Sequence. Corresponds to the JSON property computedReleaseChannel

Returns:

  • (String)


6100
6101
6102
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6100

def computed_release_channel
  @computed_release_channel
end

#create_timeString

Output only. The timestamp at which the Rollout Sequence was created. Corresponds to the JSON property createTime

Returns:

  • (String)


6105
6106
6107
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6105

def create_time
  @create_time
end

#delete_timeString

Output only. The timestamp at the Rollout Sequence was deleted. Corresponds to the JSON property deleteTime

Returns:

  • (String)


6110
6111
6112
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6110

def delete_time
  @delete_time
end

#display_nameString

Optional. Human readable display name of the Rollout Sequence. Corresponds to the JSON property displayName

Returns:

  • (String)


6115
6116
6117
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6115

def display_name
  @display_name
end

#effective_auto_upgrade_configGoogle::Apis::GkehubV1beta::AutoUpgradeConfig

Configuration for automatic upgrades. Corresponds to the JSON property effectiveAutoUpgradeConfig



6120
6121
6122
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6120

def effective_auto_upgrade_config
  @effective_auto_upgrade_config
end

#etagString

Output only. etag of the Rollout Sequence Ex. abc1234 Corresponds to the JSON property etag

Returns:

  • (String)


6125
6126
6127
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6125

def etag
  @etag
end

#ignored_clusters_selectorGoogle::Apis::GkehubV1beta::ClusterSelector

Selector for clusters. Corresponds to the JSON property ignoredClustersSelector



6130
6131
6132
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6130

def ignored_clusters_selector
  @ignored_clusters_selector
end

#labelsHash<String,String>

Optional. Labels for this Rollout Sequence. Corresponds to the JSON property labels

Returns:

  • (Hash<String,String>)


6135
6136
6137
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6135

def labels
  @labels
end

#last_qualified_control_plane_versionString

Output only. The last qualified control plane version. Corresponds to the JSON property lastQualifiedControlPlaneVersion

Returns:

  • (String)


6140
6141
6142
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6140

def last_qualified_control_plane_version
  @last_qualified_control_plane_version
end

#last_qualified_node_versionString

Output only. The last qualified node version. Corresponds to the JSON property lastQualifiedNodeVersion

Returns:

  • (String)


6145
6146
6147
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6145

def last_qualified_node_version
  @last_qualified_node_version
end

#nameString

Identifier. Name of the rollout sequence in the format of: projects/ PROJECT_ID/locations/global/rolloutSequences/NAME Corresponds to the JSON property name

Returns:

  • (String)


6151
6152
6153
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6151

def name
  @name
end

#operational_stateGoogle::Apis::GkehubV1beta::OperationalState

Operational state of the Rollout Sequence. Corresponds to the JSON property operationalState



6156
6157
6158
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6156

def operational_state
  @operational_state
end

#stagesArray<Google::Apis::GkehubV1beta::Stage>

Required. Ordered list of stages that constitutes this Rollout. Corresponds to the JSON property stages



6161
6162
6163
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6161

def stages
  @stages
end

#target_control_plane_versionString

Output only. The target control plane version of the Rollout Sequence. Corresponds to the JSON property targetControlPlaneVersion

Returns:

  • (String)


6166
6167
6168
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6166

def target_control_plane_version
  @target_control_plane_version
end

#target_node_versionString

Output only. The target node version of the Rollout Sequence. Corresponds to the JSON property targetNodeVersion

Returns:

  • (String)


6171
6172
6173
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6171

def target_node_version
  @target_node_version
end

#uidString

Output only. Google-generated UUID for this resource. This is unique across all Rollout Sequence resources. If a Rollout Sequence resource is deleted and another resource with the same name is created, it gets a different uid. Corresponds to the JSON property uid

Returns:

  • (String)


6178
6179
6180
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6178

def uid
  @uid
end

#update_timeString

Output only. The timestamp at which the Rollout Sequence was last updated. Corresponds to the JSON property updateTime

Returns:

  • (String)


6183
6184
6185
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6183

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6190
6191
6192
6193
6194
6195
6196
6197
6198
6199
6200
6201
6202
6203
6204
6205
6206
6207
6208
6209
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6190

def update!(**args)
  @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config)
  @computed_release_channel = args[:computed_release_channel] if args.key?(:computed_release_channel)
  @create_time = args[:create_time] if args.key?(:create_time)
  @delete_time = args[:delete_time] if args.key?(:delete_time)
  @display_name = args[:display_name] if args.key?(:display_name)
  @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config)
  @etag = args[:etag] if args.key?(:etag)
  @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector)
  @labels = args[:labels] if args.key?(:labels)
  @last_qualified_control_plane_version = args[:last_qualified_control_plane_version] if args.key?(:last_qualified_control_plane_version)
  @last_qualified_node_version = args[:last_qualified_node_version] if args.key?(:last_qualified_node_version)
  @name = args[:name] if args.key?(:name)
  @operational_state = args[:operational_state] if args.key?(:operational_state)
  @stages = args[:stages] if args.key?(:stages)
  @target_control_plane_version = args[:target_control_plane_version] if args.key?(:target_control_plane_version)
  @target_node_version = args[:target_node_version] if args.key?(:target_node_version)
  @uid = args[:uid] if args.key?(:uid)
  @update_time = args[:update_time] if args.key?(:update_time)
end