Class: Google::Apis::GkehubV1beta::RolloutSequence
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::RolloutSequence
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
RolloutSequence defines the desired order of upgrades. Next ID: 20
Instance Attribute Summary collapse
-
#auto_upgrade_config ⇒ Google::Apis::GkehubV1beta::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#display_name ⇒ String
Optional.
-
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1beta::AutoUpgradeConfig
Configuration for automatic upgrades.
-
#etag ⇒ String
Output only.
-
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
Identifier.
-
#operational_state ⇒ Google::Apis::GkehubV1beta::OperationalState
Operational state of the Rollout Sequence.
-
#stages ⇒ Array<Google::Apis::GkehubV1beta::Stage>
Required.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutSequence
constructor
A new instance of RolloutSequence.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutSequence
Returns a new instance of RolloutSequence.
6134 6135 6136 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6134 def initialize(**args) update!(**args) end |
Instance Attribute Details
#auto_upgrade_config ⇒ Google::Apis::GkehubV1beta::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property autoUpgradeConfig
6069 6070 6071 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6069 def auto_upgrade_config @auto_upgrade_config end |
#create_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was created.
Corresponds to the JSON property createTime
6074 6075 6076 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6074 def create_time @create_time end |
#delete_time ⇒ String
Output only. The timestamp at the Rollout Sequence was deleted.
Corresponds to the JSON property deleteTime
6079 6080 6081 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6079 def delete_time @delete_time end |
#display_name ⇒ String
Optional. Human readable display name of the Rollout Sequence.
Corresponds to the JSON property displayName
6084 6085 6086 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6084 def display_name @display_name end |
#effective_auto_upgrade_config ⇒ Google::Apis::GkehubV1beta::AutoUpgradeConfig
Configuration for automatic upgrades.
Corresponds to the JSON property effectiveAutoUpgradeConfig
6089 6090 6091 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6089 def effective_auto_upgrade_config @effective_auto_upgrade_config end |
#etag ⇒ String
Output only. etag of the Rollout Sequence Ex. abc1234
Corresponds to the JSON property etag
6094 6095 6096 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6094 def etag @etag end |
#ignored_clusters_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
Corresponds to the JSON property ignoredClustersSelector
6099 6100 6101 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6099 def ignored_clusters_selector @ignored_clusters_selector end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Rollout Sequence.
Corresponds to the JSON property labels
6104 6105 6106 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6104 def labels @labels end |
#name ⇒ String
Identifier. Name of the rollout sequence in the format of: projects/
PROJECT_ID/locations/global/rolloutSequences/NAME
Corresponds to the JSON property name
6110 6111 6112 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6110 def name @name end |
#operational_state ⇒ Google::Apis::GkehubV1beta::OperationalState
Operational state of the Rollout Sequence.
Corresponds to the JSON property operationalState
6115 6116 6117 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6115 def operational_state @operational_state end |
#stages ⇒ Array<Google::Apis::GkehubV1beta::Stage>
Required. Ordered list of stages that constitutes this Rollout.
Corresponds to the JSON property stages
6120 6121 6122 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6120 def stages @stages end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all Rollout Sequence resources. If a Rollout Sequence resource is deleted and
another resource with the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6127 6128 6129 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6127 def uid @uid end |
#update_time ⇒ String
Output only. The timestamp at which the Rollout Sequence was last updated.
Corresponds to the JSON property updateTime
6132 6133 6134 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6132 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6139 6140 6141 6142 6143 6144 6145 6146 6147 6148 6149 6150 6151 6152 6153 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6139 def update!(**args) @auto_upgrade_config = args[:auto_upgrade_config] if args.key?(:auto_upgrade_config) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @display_name = args[:display_name] if args.key?(:display_name) @effective_auto_upgrade_config = args[:effective_auto_upgrade_config] if args.key?(:effective_auto_upgrade_config) @etag = args[:etag] if args.key?(:etag) @ignored_clusters_selector = args[:ignored_clusters_selector] if args.key?(:ignored_clusters_selector) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @operational_state = args[:operational_state] if args.key?(:operational_state) @stages = args[:stages] if args.key?(:stages) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |