Class: Google::Apis::GkehubV1beta::RolloutStage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::RolloutStage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Stage represents a single stage in the Rollout.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
-
#end_time ⇒ String
Optional.
-
#fleet_projects ⇒ Array<String>
Output only.
-
#soak_duration ⇒ String
Optional.
-
#stage_number ⇒ Fixnum
Output only.
-
#start_time ⇒ String
Optional.
-
#state ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ RolloutStage
constructor
A new instance of RolloutStage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ RolloutStage
Returns a new instance of RolloutStage.
6252 6253 6254 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6252 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6219 6220 6221 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6219 def cluster_selector @cluster_selector end |
#end_time ⇒ String
Optional. Output only. The time at which the stage ended.
Corresponds to the JSON property endTime
6224 6225 6226 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6224 def end_time @end_time end |
#fleet_projects ⇒ Array<String>
Output only. The fleet projects from the sequence that was used to create this
stage. Expected format: projects/project_number
Corresponds to the JSON property fleetProjects
6230 6231 6232 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6230 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Duration to soak after this stage before starting the next stage.
Corresponds to the JSON property soakDuration
6235 6236 6237 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6235 def soak_duration @soak_duration end |
#stage_number ⇒ Fixnum
Output only. The stage number to which this status applies.
Corresponds to the JSON property stageNumber
6240 6241 6242 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6240 def stage_number @stage_number end |
#start_time ⇒ String
Optional. Output only. The time at which the stage started.
Corresponds to the JSON property startTime
6245 6246 6247 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6245 def start_time @start_time end |
#state ⇒ String
Output only. The state of the stage.
Corresponds to the JSON property state
6250 6251 6252 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6250 def state @state end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6257 6258 6259 6260 6261 6262 6263 6264 6265 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6257 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @end_time = args[:end_time] if args.key?(:end_time) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) @stage_number = args[:stage_number] if args.key?(:stage_number) @start_time = args[:start_time] if args.key?(:start_time) @state = args[:state] if args.key?(:state) end |