Class: Google::Apis::GkehubV1beta::Scope
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Scope
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Scope represents a Scope in a Fleet.
Instance Attribute Summary collapse
-
#create_time ⇒ String
Output only.
-
#delete_time ⇒ String
Output only.
-
#labels ⇒ Hash<String,String>
Optional.
-
#name ⇒ String
The resource name for the scope
projects/project/locations/location/ scopes/scope`Corresponds to the JSON propertyname`. -
#namespace_labels ⇒ Hash<String,String>
Optional.
-
#state ⇒ Google::Apis::GkehubV1beta::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
-
#uid ⇒ String
Output only.
-
#update_time ⇒ String
Output only.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Scope
constructor
A new instance of Scope.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Scope
Returns a new instance of Scope.
6368 6369 6370 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6368 def initialize(**args) update!(**args) end |
Instance Attribute Details
#create_time ⇒ String
Output only. When the scope was created.
Corresponds to the JSON property createTime
6324 6325 6326 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6324 def create_time @create_time end |
#delete_time ⇒ String
Output only. When the scope was deleted.
Corresponds to the JSON property deleteTime
6329 6330 6331 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6329 def delete_time @delete_time end |
#labels ⇒ Hash<String,String>
Optional. Labels for this Scope.
Corresponds to the JSON property labels
6334 6335 6336 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6334 def labels @labels end |
#name ⇒ String
The resource name for the scope projects/project/locations/location/
scopes/scope`
Corresponds to the JSON propertyname`
6340 6341 6342 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6340 def name @name end |
#namespace_labels ⇒ Hash<String,String>
Optional. Scope-level cluster namespace labels. For the member clusters bound
to the Scope, these labels are applied to each namespace under the Scope.
Scope-level labels take precedence over Namespace-level labels (
namespace_labels in the Fleet Namespace resource) if they share a key. Keys
and values must be Kubernetes-conformant.
Corresponds to the JSON property namespaceLabels
6349 6350 6351 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6349 def namespace_labels @namespace_labels end |
#state ⇒ Google::Apis::GkehubV1beta::ScopeLifecycleState
ScopeLifecycleState describes the state of a Scope resource.
Corresponds to the JSON property state
6354 6355 6356 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6354 def state @state end |
#uid ⇒ String
Output only. Google-generated UUID for this resource. This is unique across
all scope resources. If a scope resource is deleted and another resource with
the same name is created, it gets a different uid.
Corresponds to the JSON property uid
6361 6362 6363 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6361 def uid @uid end |
#update_time ⇒ String
Output only. When the scope was last updated.
Corresponds to the JSON property updateTime
6366 6367 6368 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6366 def update_time @update_time end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6373 6374 6375 6376 6377 6378 6379 6380 6381 6382 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6373 def update!(**args) @create_time = args[:create_time] if args.key?(:create_time) @delete_time = args[:delete_time] if args.key?(:delete_time) @labels = args[:labels] if args.key?(:labels) @name = args[:name] if args.key?(:name) @namespace_labels = args[:namespace_labels] if args.key?(:namespace_labels) @state = args[:state] if args.key?(:state) @uid = args[:uid] if args.key?(:uid) @update_time = args[:update_time] if args.key?(:update_time) end |