Class: Google::Apis::GkehubV1beta::ServiceMeshCondition
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::ServiceMeshCondition
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Condition being reported.
Instance Attribute Summary collapse
-
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable to the user.
-
#details ⇒ String
A short summary about the issue.
-
#documentation_link ⇒ String
Links contains actionable information.
-
#severity ⇒ String
Severity level of the condition.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ServiceMeshCondition
constructor
A new instance of ServiceMeshCondition.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ServiceMeshCondition
Returns a new instance of ServiceMeshCondition.
6492 6493 6494 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6492 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
Unique identifier of the condition which describes the condition recognizable
to the user.
Corresponds to the JSON property code
6475 6476 6477 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6475 def code @code end |
#details ⇒ String
A short summary about the issue.
Corresponds to the JSON property details
6480 6481 6482 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6480 def details @details end |
#documentation_link ⇒ String
Links contains actionable information.
Corresponds to the JSON property documentationLink
6485 6486 6487 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6485 def documentation_link @documentation_link end |
#severity ⇒ String
Severity level of the condition.
Corresponds to the JSON property severity
6490 6491 6492 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6490 def severity @severity end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6497 6498 6499 6500 6501 6502 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6497 def update!(**args) @code = args[:code] if args.key?(:code) @details = args[:details] if args.key?(:details) @documentation_link = args[:documentation_link] if args.key?(:documentation_link) @severity = args[:severity] if args.key?(:severity) end |