Class: Google::Apis::GkehubV1beta::Stage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Stage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Rollout stage.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
-
#fleet_projects ⇒ Array<String>
Required.
-
#soak_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stage
constructor
A new instance of Stage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stage
Returns a new instance of Stage.
6749 6750 6751 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6749 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6736 6737 6738 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6736 def cluster_selector @cluster_selector end |
#fleet_projects ⇒ Array<String>
Required. List of Fleet projects to select the clusters from. Expected format:
projects/project
Corresponds to the JSON property fleetProjects
6742 6743 6744 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6742 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Soak time after upgrading all the clusters in the stage.
Corresponds to the JSON property soakDuration
6747 6748 6749 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6747 def soak_duration @soak_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6754 6755 6756 6757 6758 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6754 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) end |