Class: Google::Apis::GkehubV1beta::Stage

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

Rollout stage.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Stage

Returns a new instance of Stage.



6740
6741
6742
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6740

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#cluster_selectorGoogle::Apis::GkehubV1beta::ClusterSelector

Selector for clusters. Corresponds to the JSON property clusterSelector



6727
6728
6729
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6727

def cluster_selector
  @cluster_selector
end

#fleet_projectsArray<String>

Required. List of Fleet projects to select the clusters from. Expected format: projects/project Corresponds to the JSON property fleetProjects

Returns:

  • (Array<String>)


6733
6734
6735
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6733

def fleet_projects
  @fleet_projects
end

#soak_durationString

Optional. Soak time after upgrading all the clusters in the stage. Corresponds to the JSON property soakDuration

Returns:

  • (String)


6738
6739
6740
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6738

def soak_duration
  @soak_duration
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6745
6746
6747
6748
6749
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6745

def update!(**args)
  @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector)
  @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects)
  @soak_duration = args[:soak_duration] if args.key?(:soak_duration)
end