Class: Google::Apis::GkehubV1beta::Stage
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::Stage
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
Rollout stage.
Instance Attribute Summary collapse
-
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
-
#fleet_projects ⇒ Array<String>
Required.
-
#soak_duration ⇒ String
Optional.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Stage
constructor
A new instance of Stage.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Stage
Returns a new instance of Stage.
6652 6653 6654 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6652 def initialize(**args) update!(**args) end |
Instance Attribute Details
#cluster_selector ⇒ Google::Apis::GkehubV1beta::ClusterSelector
Selector for clusters.
Corresponds to the JSON property clusterSelector
6639 6640 6641 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6639 def cluster_selector @cluster_selector end |
#fleet_projects ⇒ Array<String>
Required. List of Fleet projects to select the clusters from. Expected format:
projects/project
Corresponds to the JSON property fleetProjects
6645 6646 6647 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6645 def fleet_projects @fleet_projects end |
#soak_duration ⇒ String
Optional. Soak time after upgrading all the clusters in the stage.
Corresponds to the JSON property soakDuration
6650 6651 6652 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6650 def soak_duration @soak_duration end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6657 6658 6659 6660 6661 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6657 def update!(**args) @cluster_selector = args[:cluster_selector] if args.key?(:cluster_selector) @fleet_projects = args[:fleet_projects] if args.key?(:fleet_projects) @soak_duration = args[:soak_duration] if args.key?(:soak_duration) end |