Class: Google::Apis::GkehubV1beta::WorkloadIdentityFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

WorkloadIdentity: Global feature state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityFeatureState

Returns a new instance of WorkloadIdentityFeatureState.



6962
6963
6964
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6962

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_state_detailsHash<String,Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail>

The state of the IAM namespaces for the fleet. Corresponds to the JSON property namespaceStateDetails



6939
6940
6941
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6939

def namespace_state_details
  @namespace_state_details
end

#namespace_statesHash<String,String>

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property namespaceStates

Returns:

  • (Hash<String,String>)


6945
6946
6947
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6945

def namespace_states
  @namespace_states
end

#scope_tenancy_workload_identity_poolString

The full name of the scope-tenancy pool for the fleet. Corresponds to the JSON property scopeTenancyWorkloadIdentityPool

Returns:

  • (String)


6950
6951
6952
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6950

def scope_tenancy_workload_identity_pool
  @scope_tenancy_workload_identity_pool
end

#workload_identity_poolString

The full name of the svc.id.goog pool for the fleet. Corresponds to the JSON property workloadIdentityPool

Returns:

  • (String)


6955
6956
6957
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6955

def workload_identity_pool
  @workload_identity_pool
end

#workload_identity_pool_state_detailsHash<String,Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail>

The state of the Workload Identity Pools for the fleet. Corresponds to the JSON property workloadIdentityPoolStateDetails



6960
6961
6962
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6960

def workload_identity_pool_state_details
  @workload_identity_pool_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6967
6968
6969
6970
6971
6972
6973
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6967

def update!(**args)
  @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details)
  @namespace_states = args[:namespace_states] if args.key?(:namespace_states)
  @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool)
  @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool)
  @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details)
end