Class: Google::Apis::GkehubV1beta::WorkloadIdentityFeatureState

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb

Overview

WorkloadIdentity: Global feature state.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ WorkloadIdentityFeatureState

Returns a new instance of WorkloadIdentityFeatureState.



6831
6832
6833
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6831

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#namespace_state_detailsHash<String,Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail>

The state of the IAM namespaces for the fleet. Corresponds to the JSON property namespaceStateDetails



6808
6809
6810
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6808

def namespace_state_details
  @namespace_state_details
end

#namespace_statesHash<String,String>

Deprecated, this field will be erased after code is changed to use the new field. Corresponds to the JSON property namespaceStates

Returns:

  • (Hash<String,String>)


6814
6815
6816
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6814

def namespace_states
  @namespace_states
end

#scope_tenancy_workload_identity_poolString

The full name of the scope-tenancy pool for the fleet. Corresponds to the JSON property scopeTenancyWorkloadIdentityPool

Returns:

  • (String)


6819
6820
6821
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6819

def scope_tenancy_workload_identity_pool
  @scope_tenancy_workload_identity_pool
end

#workload_identity_poolString

The full name of the svc.id.goog pool for the fleet. Corresponds to the JSON property workloadIdentityPool

Returns:

  • (String)


6824
6825
6826
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6824

def workload_identity_pool
  @workload_identity_pool
end

#workload_identity_pool_state_detailsHash<String,Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail>

The state of the Workload Identity Pools for the fleet. Corresponds to the JSON property workloadIdentityPoolStateDetails



6829
6830
6831
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6829

def workload_identity_pool_state_details
  @workload_identity_pool_state_details
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6836
6837
6838
6839
6840
6841
6842
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6836

def update!(**args)
  @namespace_state_details = args[:namespace_state_details] if args.key?(:namespace_state_details)
  @namespace_states = args[:namespace_states] if args.key?(:namespace_states)
  @scope_tenancy_workload_identity_pool = args[:scope_tenancy_workload_identity_pool] if args.key?(:scope_tenancy_workload_identity_pool)
  @workload_identity_pool = args[:workload_identity_pool] if args.key?(:workload_identity_pool)
  @workload_identity_pool_state_details = args[:workload_identity_pool_state_details] if args.key?(:workload_identity_pool_state_details)
end