Class: Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
7042 7043 7044 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7042 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
7035 7036 7037 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7035 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
7040 7041 7042 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7040 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7047 7048 7049 7050 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 7047 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |