Class: Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityNamespaceStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
NamespaceStateDetail represents the state of a IAM namespace.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the IAM namespace.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
constructor
A new instance of WorkloadIdentityNamespaceStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityNamespaceStateDetail
Returns a new instance of WorkloadIdentityNamespaceStateDetail.
6911 6912 6913 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6911 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the IAM namespace.
Corresponds to the JSON property code
6904 6905 6906 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6904 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
6909 6910 6911 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6909 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6916 6917 6918 6919 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6916 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |