Class: Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail
- Inherits:
-
Object
- Object
- Google::Apis::GkehubV1beta::WorkloadIdentityWorkloadIdentityPoolStateDetail
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/gkehub_v1beta/classes.rb,
lib/google/apis/gkehub_v1beta/representations.rb,
lib/google/apis/gkehub_v1beta/representations.rb
Overview
WorkloadIdentityPoolStateDetail represents the state of the Workload Identity Pools for the fleet.
Instance Attribute Summary collapse
-
#code ⇒ String
The state of the Workload Identity Pool.
-
#description ⇒ String
A human-readable description of the current state or returned error.
Instance Method Summary collapse
-
#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail
constructor
A new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ WorkloadIdentityWorkloadIdentityPoolStateDetail
Returns a new instance of WorkloadIdentityWorkloadIdentityPoolStateDetail.
6937 6938 6939 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6937 def initialize(**args) update!(**args) end |
Instance Attribute Details
#code ⇒ String
The state of the Workload Identity Pool.
Corresponds to the JSON property code
6930 6931 6932 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6930 def code @code end |
#description ⇒ String
A human-readable description of the current state or returned error.
Corresponds to the JSON property description
6935 6936 6937 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6935 def description @description end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6942 6943 6944 6945 |
# File 'lib/google/apis/gkehub_v1beta/classes.rb', line 6942 def update!(**args) @code = args[:code] if args.key?(:code) @description = args[:description] if args.key?(:description) end |